@@ -38,14 +38,15 @@ extern "C" {
 
 struct KNSManager;
 
+rc_t KServiceMakeWithMgr(KService ** self, const struct VFSManager * vMgr,
+    const struct KNSManager * mgr, struct KConfig * kfg);
 
 rc_t KServiceNamesQueryExt ( KService * self, VRemoteProtocols protocols, 
-                             const char * cgi, const char * version,
-                             const KSrvResponse ** response );
+    const char * cgi, const char * version, const char * outDir,
+    const char * outFile, const KSrvResponse ** response );
 
 rc_t KServiceNamesExecuteExt ( KService * self, VRemoteProtocols protocols, 
-    const char * cgi, const char * version,
-    const struct KSrvResponse ** result );
+    const char * cgi, const char * version, const KSrvResponse ** result );
 
 rc_t KServiceSearchExecuteExt ( KService * self,
     const char * cgi, const char * version,
@@ -54,13 +55,24 @@ rc_t KServiceSearchExecuteExt ( KService * self,
 
 rc_t KServiceTestNamesExecuteExt ( KService * self, VRemoteProtocols protocols, 
     const char * cgi, const char * version,
-    const struct KSrvResponse ** result, const char * expected );
+    const KSrvResponse ** result, const char * expected );
+
+
+rc_t KServiceTestNamesQueryExt ( KService * self, VRemoteProtocols protocols, 
+    const char * cgi, const char * version, const KSrvResponse ** result,
+    const char * dir, const char * file, const char * expected );
 
 
 rc_t KService1Search ( const struct KNSManager * mgr, const char * cgi,
     const char * acc, const struct Kart ** result );
 
 
+rc_t KSrvRespFileGetHttp ( const KSrvRespFile * self,
+                           const struct VPath ** path );
+
+/* DON'T FREE RETURNED STRINGS !!! */
+rc_t KSrvRespFileGetName(const struct KSrvRespFile * self, const char ** name);
+
 
 #ifdef __cplusplus
 }
