@@ -605,7 +605,8 @@ rc_t KDBOpenFileAsDirectory (const KDirectory * dir,
 
 static rc_t KDBOpenPathTypeReadInt ( const KDBManager * mgr, const KDirectory * dir, const char * path,
                                      const KDirectory ** pdir, int * type,
-                                     int pathtype, uint32_t rcobj, bool try_srapath )
+                                     int pathtype, uint32_t rcobj, bool try_srapath,
+                                     const VPath * aVpath )
 {
     VFSManager * vmgr = mgr->vfsmgr;
     const KDirectory * ldir = NULL;
@@ -620,7 +621,7 @@ static rc_t KDBOpenPathTypeReadInt ( const KDBManager * mgr, const KDirectory *
     }
     else
     {
-        VPath * vpath;
+        VPath * vpath = ( VPath * ) aVpath;
 
         /*
          * We've got to decide if the path coming in is a full or relative
@@ -628,7 +629,7 @@ static rc_t KDBOpenPathTypeReadInt ( const KDBManager * mgr, const KDirectory *
          * accession
          *
          */
-        rc = VPathMakeDirectoryRelative ( &vpath, dir, path );
+        rc = VPathMakeDirectoryRelativeVPath ( &vpath, dir, path, vpath );
         if ( rc == 0 )
         {
             rc = VFSManagerOpenDirectoryReadDirectoryRelativeDecrypt ( vmgr, dir, &ldir, vpath );
@@ -654,14 +655,16 @@ static rc_t KDBOpenPathTypeReadInt ( const KDBManager * mgr, const KDirectory *
                         KDirectoryRelease( ldir );
                 }
             }
-            VPathRelease ( vpath );
+            if ( aVpath == NULL )
+                VPathRelease ( vpath );
         }
     }
     return rc;
 }
 
 rc_t KDBOpenPathTypeRead ( const KDBManager * mgr, const KDirectory * dir, const char * path, 
-    const KDirectory ** pdir, int pathtype, int * ppathtype, bool try_srapath )
+    const KDirectory ** pdir, int pathtype, int * ppathtype, bool try_srapath,
+    const VPath * vpath )
 {
     const KDirectory *ldir;
     rc_t rc = 0;
@@ -697,7 +700,8 @@ rc_t KDBOpenPathTypeRead ( const KDBManager * mgr, const KDirectory * dir, const
         break;
     }
 
-    rc = KDBOpenPathTypeReadInt( mgr, dir, path, &ldir, &type, pathtype, rcobj, try_srapath );
+    rc = KDBOpenPathTypeReadInt( mgr, dir, path, &ldir, &type, pathtype, rcobj,
+        try_srapath, vpath );
 
     if (rc == 0)
     {
