@@ -27,6 +27,7 @@
 #include <kfg/config.h> /* KConfigMake */
 #include <kfg/kart-priv.h> /* KartMake2 */
 #include <kfg/keystore.h> /* KKeyStoreRelease */
+#include <kfg/ngc.h> /* KNgcObj */
 #include <kfg/repository.h> /* KRepositoryMgr */
 
 #include <kfs/directory.h> /* KDirectoryOpenFileRead */
@@ -316,7 +317,8 @@ rc_t CC KartItemItemDesc(const KartItem *self, const String **elem)
     }
     return rc;
 }
-LIB_EXPORT rc_t CC KartItemObjType (const KartItem *self, const String **elem )
+LIB_EXPORT
+rc_t CC KartItemObjType (const KartItem *self, const String **elem )
 {
     rc_t rc = KartItemCheck(self, elem);
     if (rc == 0) {
@@ -324,7 +326,8 @@ LIB_EXPORT rc_t CC KartItemObjType (const KartItem *self, const String **elem )
     }
     return rc;
 }
-LIB_EXPORT rc_t CC KartItemPath (const KartItem *self, const String **elem )
+LIB_EXPORT
+rc_t CC KartItemPath (const KartItem *self, const String **elem )
 {
     rc_t rc = KartItemCheck(self, elem);
     if (rc == 0) {
@@ -332,7 +335,8 @@ LIB_EXPORT rc_t CC KartItemPath (const KartItem *self, const String **elem )
     }
     return rc;
 }
-LIB_EXPORT rc_t CC KartItemSize (const KartItem *self, const String **elem )
+LIB_EXPORT
+rc_t CC KartItemSize (const KartItem *self, const String **elem )
 {
     rc_t rc = KartItemCheck(self, elem);
     if (rc == 0) {
@@ -371,10 +375,12 @@ struct Kart {
     uint64_t len;
     uint16_t itemsProcessed;
 
-    KKeyStore * keystore;
+    KKeyStore *keystore;
 
     /* version eVersion2 0x02000000 */
     Vector rows;
+
+    const KNgcObj *ngcObj;
 };
 
 static void whackKartItem ( void * self, void * ignore ) {
@@ -394,6 +400,8 @@ static void KartWhack(Kart *self) {
 
     KRepositoryMgrRelease ( self -> mgr );
 
+    KNgcObjRelease ( self -> ngcObj );
+
     memset(self, 0, sizeof *self);
 
     free(self);
@@ -429,7 +437,9 @@ LIB_EXPORT rc_t CC KartRelease(const Kart *self) {
     return 0;
 }
 
-LIB_EXPORT rc_t CC KartItemsProcessed(const Kart *self, uint16_t *number) {
+LIB_EXPORT
+rc_t CC KartItemsProcessed(const Kart *self, uint16_t *number)
+{
     if (number == NULL) {
         return RC(rcKFG, rcFile, rcLoading, rcParam, rcNull);
     }
@@ -623,7 +633,17 @@ LIB_EXPORT rc_t CC KartPrintNumbered(const Kart *self) {
     return rc;
 }
 
-static rc_t KartRegisterObject ( const Kart * self, const KartItem * item ) {
+LIB_EXPORT rc_t CC KartItemGetTicket(const KartItem *self,
+    char * ticket, size_t ticket_size, size_t * written)
+{
+    if (self == NULL)
+        return RC(rcKFG, rcFile, rcAccessing, rcSelf, rcNull);
+    return KNgcObjGetTicket(self->dad->ngcObj, ticket, ticket_size, written);
+}
+
+static
+rc_t KartRegisterObject ( const Kart * self, const KartItem * item )
+{
     rc_t rc = 0;
 
     const KRepository * repo = NULL;
@@ -665,20 +685,24 @@ static rc_t KartRegisterObject ( const Kart * self, const KartItem * item ) {
                                                     & repo );
         if ( GetRCModule ( rc ) == rcKFG && GetRCState ( rc ) == rcNotFound )
             rc = RC ( rcKFG, rcNode, rcAccessing, rcNode, rcNotFound );
-    }
-    if ( rc == 0 ) {
-        rc = KRepositoryDownloadTicket ( repo, ticket, sizeof ticket, NULL );
-        if ( GetRCState ( rc ) == rcNotFound )
-            rc = RC ( rcKFG, rcNode, rcAccessing, rcNode, rcNotFound );
-    }
-    if ( rc == 0 ) {
-        if ( acc != NULL && acc -> size != 0 )
-            rc = string_printf ( b, sizeof b, & id . size,
+
+        if ( rc == 0 ) {
+            rc = KRepositoryDownloadTicket( repo, ticket, sizeof ticket, NULL );
+            if ( GetRCState ( rc ) == rcNotFound )
+                rc = RC ( rcKFG, rcNode, rcAccessing, rcNode, rcNotFound );
+        }
+        else if (self->ngcObj != NULL)
+            rc = KNgcObjGetTicket(self->ngcObj, ticket, sizeof ticket, NULL);
+
+        if ( rc == 0 ) {
+            if ( acc != NULL && acc -> size != 0 )
+                rc = string_printf ( b, sizeof b, & id . size,
                                  "ncbi-acc:%S?tic=%s", acc, ticket );
-        else
-            rc = string_printf ( b, sizeof b, & id . size,
+            else
+                rc = string_printf ( b, sizeof b, & id . size,
                                  "ncbi-file:%S?tic=%s", name, ticket );
-        id . len = id . size;
+            id . len = id . size;
+        }
     }
 
     if ( rc == 0 )
@@ -957,7 +981,9 @@ LIB_EXPORT rc_t CC KartMake2 ( Kart ** kart ) {
     return 0;
 }
 
-LIB_EXPORT rc_t CC KartAddRow ( Kart * self, const char * row, size_t size ) {
+LIB_EXPORT rc_t CC KartAddRow ( Kart * self,
+    const char * row, size_t size )
+{
     if ( self == NULL )
         return RC ( rcKFG, rcFile, rcUpdating, rcSelf, rcNull );
     if ( row == NULL )
@@ -987,8 +1013,29 @@ LIB_EXPORT rc_t CC KartAddRow ( Kart * self, const char * row, size_t size ) {
     }
 }
 
-LIB_EXPORT rc_t CC KartMake(const KDirectory *dir, const char *path,
-    Kart **kart, bool *isKart)
+static rc_t KartNgcInit(Kart * self,
+    const char *ngcPath, const KDirectory *dir)
+{
+    if (ngcPath == NULL)
+        return 0;
+
+    else {
+        const KFile * f = NULL;
+        rc_t rc = KDirectoryOpenFileRead(dir, &f, "%s", ngcPath);
+
+        if (rc == 0) {
+            assert(self);
+            rc = KNgcObjMakeFromFile(&self->ngcObj, f);
+        }
+
+        RELEASE(KFile, f);
+
+        return rc;
+    }
+}
+
+LIB_EXPORT rc_t CC KartMakeWithNgc(const KDirectory *dir, const char *path,
+    Kart **kart, bool *isKart, const char *ngcPath)
 {
     rc_t rc = 0;
     const KFile *f = NULL;
@@ -1035,6 +1082,9 @@ LIB_EXPORT rc_t CC KartMake(const KDirectory *dir, const char *path,
             rc = KConfigMakeRepositoryMgrRead ( kfg, & obj -> mgr );
         RELEASE ( KConfig, kfg );
 
+        if (rc == 0)
+            rc = KartNgcInit(obj, ngcPath, dir);
+
         if (rc == 0) {
             KRefcountInit(&obj->refcount, 1, "Kart", "Make", "kart");
             *kart = obj;
@@ -1045,5 +1095,12 @@ LIB_EXPORT rc_t CC KartMake(const KDirectory *dir, const char *path,
     }
 
     RELEASE(KFile, f);
+
     return rc;
 }
+
+LIB_EXPORT rc_t CC KartMake(const KDirectory *dir, const char *path,
+    Kart **kart, bool *isKart)
+{
+    return KartMakeWithNgc(dir, path, kart, isKart, NULL);
+}
