@@ -141,7 +141,7 @@ const char *KSysDirEnumNext ( const KSysDirEnum *self )
             case '.':
                 if ( e -> d_name [ 2 ] == 0 )
                     continue;
-                break; 
+                break;
             }
         }
 
@@ -257,7 +257,7 @@ rc_t KSysDirListingInit ( KSysDirListing *self, const char *path, const KDirecto
                         if ( ! ( * f ) ( dir, name, data ) )
                             continue;
                     }
-                    
+
                     if ( self -> cnt == len )
                     {
                         len += len;
@@ -369,14 +369,14 @@ rc_t KSysDirCanonPath_v1 ( const KSysDir_v1 * self, enum RCContext ctx, char *pa
         /* detect special sequences */
         switch ( src - last )
         {
-        case 1: 
+        case 1:
             if ( last [ 1 ] == '/' )
             {
                 /* "//" -> "/" */
                 last = src;
             }
             break;
-            
+
         case 2:
             if ( last [ 1 ] == '.' )
             {
@@ -411,7 +411,7 @@ rc_t KSysDirCanonPath_v1 ( const KSysDir_v1 * self, enum RCContext ctx, char *pa
 
         /* move destination ahead */
         dst += src - last;
-        
+
         /* if we're done, go */
         if ( src == end )
                 break;
@@ -615,7 +615,7 @@ uint32_t KSysDirFullPathType_v1 ( const char *path )
             return kptNotFound | alias;
         default:
             return kptBadPath | alias;
-        } 
+        }
     }
 
     /* not a bad assumption */
@@ -718,7 +718,7 @@ rc_t KSysDirVisitDir ( KSysDirVisitData *pb )
             }
         }
 
-        
+
         KSysDirEnumWhack ( & listing );
     }
     return rc;
@@ -852,6 +852,7 @@ rc_t KSysDirResolvePath_v1 ( const KSysDir_v1 * self, bool absolute,
     if ( rc == 0 )
     {
         uint32_t path_size = strlen ( full );
+        PLOGMSG(klogDebug, (klogDebug, "KSysDirResolvePath_v1 = '$(res)'", "res=%s", full));
 
         if ( absolute )
         {
@@ -1077,7 +1078,7 @@ rc_t KSysDirRename_v1 ( KSysDir_v1 * self, bool force, const char *from, const c
                         if (tchanged)
                             KSysDirSetAccess_v1 (self, false, taccess, 0222, to, NULL);
                     }
-                        
+
                 }
 
             }
@@ -2023,7 +2024,7 @@ rc_t KSysDirCreateFile_v1 ( KSysDir_v1 * self, KFile_v1 **f, bool update,
                 rc = RC ( rcFS, rcDirectory, rcCreating, rcNoObj, rcUnknown );
                 break;
             }
-            
+
             /* disabled 12/12/2012 : it prints an error message, if vdb tries to open
                the same reference-object twice via http. The lock-file for the 2nd try
                does already exist. This is not an error, just a condition. */
@@ -2141,7 +2142,7 @@ rc_t KSysDirOpenDirRead_v1 ( const KSysDir_v1 * self,
      const KDirectory_v1 **subp, bool chroot, const char *path, va_list args )
 {
     char full [ PATH_MAX ];
-    rc_t rc; 
+    rc_t rc;
 
     rc = KSysDirMakePath_v1 ( self, rcOpening, true, full, sizeof full, path, args );
     if ( rc == 0 )
@@ -2152,13 +2153,13 @@ rc_t KSysDirOpenDirRead_v1 ( const KSysDir_v1 * self,
         size_t path_size = strlen ( full );
         while ( path_size > 1 && full [ path_size - 1 ] == '/' )
             full [ -- path_size ] = 0;
-            
+
         t = KSysDirFullPathType_v1 ( full ) & ( kptAlias - 1 );
         if ( t == kptNotFound )
             return RC ( rcFS, rcDirectory, rcOpening, rcPath, rcNotFound );
         if ( t != kptDir )
             return RC ( rcFS, rcDirectory, rcOpening, rcPath, rcIncorrect );
-        
+
         sub = KSysDirMake_v1 ( path_size );
         if ( sub == NULL )
             rc = RC ( rcFS, rcDirectory, rcOpening, rcMemory, rcExhausted );
@@ -2281,7 +2282,7 @@ rc_t KSysDirCreateDir_v1 ( KSysDir_v1 * self,
  *  returns a 64-bit key pertinent only to the particular file
  *  system device holding that file.
  *
- *  It can be used as a form of sort key except that it is not 
+ *  It can be used as a form of sort key except that it is not
  *  guaranteed to be unique.
  *
  *  "locator" [ OUT ] - return parameter for file locator
@@ -2321,7 +2322,7 @@ rc_t CC KSysDirFilePhysicalSize_v1 ( const KSysDir_v1 *self,
 /* FileContiguous
  *  returns true if the file is "contiguous".  Chunked or sparse files are not
  *  contiguous while most data files are.  Virtual generated files would likely
- *  not be contiguous.  
+ *  not be contiguous.
  *
  *  "contiguous" [ OUT ] - return parameter for file contiguous
  *
