@@ -43,7 +43,7 @@ typedef struct progressbar
     char buffer[ BUFFER_SIZE ];
 	percent_t percent;
     bool initialized;
-    int out_fd;
+    void * out_writer;
 	uint8_t digits;
 } progressbar;
 
@@ -54,17 +54,23 @@ static rc_t make_progressbar_cmn( progressbar ** pb, const uint8_t digits, bool
         rc = RC( rcVDB, rcNoTarg, rcConstructing, rcSelf, rcNull );
 	else
 	{
-		progressbar	* p = calloc( 1, sizeof( *p ) );
-		if ( p == NULL )
-			rc = RC( rcVDB, rcNoTarg, rcConstructing, rcMemory, rcExhausted );
-		else
-		{
-            p->digits = digits > MAX_DIGITS ? MAX_DIGITS : digits;
-            p->out_fd = use_stderr ? STDERR_FD : STDOUT_FD;
-            if ( sys_is_a_tty( p->out_fd ) != 1 )
-                p->out_fd = 0;
-			*pb = p;
-		}
+        void * h_stdout;
+        void * h_stderr;
+        
+        *pb = NULL;
+        rc = KWrtSysInit( &h_stdout, &h_stderr );
+        if ( rc == 0 )
+        {
+            progressbar	* p = calloc( 1, sizeof( *p ) );
+            if ( p == NULL )
+                rc = RC( rcVDB, rcNoTarg, rcConstructing, rcMemory, rcExhausted );
+            else
+            {
+                p -> digits = digits > MAX_DIGITS ? MAX_DIGITS : digits;
+                p -> out_writer = use_stderr ? h_stderr : h_stdout;
+                *pb = p;
+            }
+        }
 	}
     return rc;
 }
@@ -79,24 +85,24 @@ LIB_EXPORT rc_t CC make_progressbar_stderr( struct progressbar ** pb, const uint
     return make_progressbar_cmn( pb, digits, true );
 }
 
+rc_t CC KWrt_DefaultWriter( void * self, const char * buffer, size_t bufsize, size_t * num_writ );
+
 static rc_t write_buffer( progressbar * pb, size_t to_write )
 {
-    size_t printed = sys_simple_write( pb->out_fd, pb->buffer, to_write );
-    if ( to_write != printed )
-        return RC( rcVDB, rcNoTarg, rcWriting, rcRange, rcInvalid );
-    return 0;
+    size_t written;
+    rc_t rc = KWrt_DefaultWriter( pb -> out_writer, pb -> buffer, to_write, &written );
+    /* size_t printed = sys_simple_write( pb -> out_fd, pb -> buffer, to_write ); */
+    if ( rc == 0 && to_write != written )
+        rc = RC( rcVDB, rcNoTarg, rcWriting, rcRange, rcInvalid );
+    return rc;
 }
 
 static rc_t print_newline( progressbar * pb )
 {
-    rc_t rc = 0;
-    if ( pb->out_fd > 0 )
-    {
-        size_t num_writ;
-        rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, "\n" );
-        if ( rc == 0 )
-            rc = write_buffer( pb, num_writ );
-    }
+    size_t num_writ;
+    rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, "\n" );
+    if ( rc == 0 )
+        rc = write_buffer( pb, num_writ );
     return rc;
 }
 
@@ -111,27 +117,19 @@ LIB_EXPORT rc_t CC destroy_progressbar( progressbar * pb )
 
 static rc_t print_progress_1( progressbar * pb, const char * fmt, percent_t value )
 {
-    rc_t rc = 0;
-    if ( pb->out_fd > 0 )
-    {
-        size_t num_writ;
-        rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, fmt, value );
-        if ( rc == 0 )
-            rc = write_buffer( pb, num_writ );
-    }
+    size_t num_writ;
+    rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, fmt, value );
+    if ( rc == 0 )
+        rc = write_buffer( pb, num_writ );
     return rc;
 }
 
 static rc_t print_progress_2( progressbar * pb, const char * fmt, percent_t value1, percent_t value2 )
 {
-    rc_t rc = 0;
-    if ( pb->out_fd > 0 )
-    {
-        size_t num_writ;
-        rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, fmt, value1, value2 );
-        if ( rc == 0 )
-            rc = write_buffer( pb, num_writ );
-    }
+    size_t num_writ;
+    rc_t rc = string_printf( pb->buffer, BUFFER_SIZE, &num_writ, fmt, value1, value2 );
+    if ( rc == 0 )
+        rc = write_buffer( pb, num_writ );
     return rc;
 }
 
