@@ -51,14 +51,10 @@ struct String;
 struct KConfig;
 struct HttpRetrySpecs;
 struct KNSProxies;
+struct CloudMgr;
 
 struct KNSManager
 {
-    struct String const *aws_access_key_id;
-    struct String const *aws_secret_access_key;
-    struct String const *aws_region;
-    struct String const *aws_output;
-
     struct HttpRetrySpecs retry_specs;
 
     KTLSGlobals tlsg;
@@ -70,25 +66,43 @@ struct KNSManager
     int32_t conn_write_timeout;
     int32_t http_read_timeout;
     int32_t http_write_timeout;
-    
+
     uint32_t maxTotalWaitForReliableURLs_ms;
 
     uint8_t  maxNumberOfRetriesOnFailureForReliableURLs;
 
     struct KNSProxies * proxies;
 
-    bool verbose;
+    struct CloudMgr * cloud;
 
+    bool verbose;
+    bool logTlsErrors;
+
+    /* VResolverCache try to resolve to user's cache before cwd/AD */
+    bool resolveToCache;
+
+    /* VResolverCache ia allowed to resolve to user's cache vs. cwd/AD */
+    bool enabledResolveToAd;
+
+    bool accept_aws_charges;
+    bool accept_gcp_charges;
+
+    bool NCBI_VDB_NETnoLogError;
     bool NCBI_VDB_NETkfgValueSet;
     bool NCBI_VDB_NETkfgValue;
+
+    bool notSingleton;
 };
 
 bool KNSManagerLogNcbiVdbNetError ( const struct KNSManager * self );
+void KNSManagerSetLogNcbiVdbNetError(struct KNSManager * self, bool set);
 
 /* returns true when we should not try direct internet connection
  * when HttpProxies are set */
 bool KNSManagerHttpProxyOnly ( const struct KNSManager * self );
 
+rc_t KNSManagerGetCloudLocation(const struct KNSManager * self,
+    char * buffer, size_t bsize, size_t * num_read, size_t * remaining);
 
 /******************************** KNSProxies **********************************/
 
