@@ -155,8 +155,8 @@ rc_t CC KSocketWhack ( KSocket *self )
     assert ( self != NULL );
 
     shutdown ( self -> fd, SHUT_WR );
-    
-    while ( 1 ) 
+
+    while ( 1 )
     {
         char buffer [ 1024 ];
         ssize_t result = recv ( self -> fd, buffer, sizeof buffer, MSG_DONTWAIT );
@@ -173,7 +173,8 @@ rc_t CC KSocketWhack ( KSocket *self )
         unlink ( self -> path );
         free ( ( void* ) self -> path );
     }
-        
+
+    KStreamWhack ( & self -> dad, "KSocket" );
     free ( self );
 
     return 0;
@@ -399,6 +400,8 @@ static rc_t KSocketGetEndpointV4 ( const KSocket * self, KEndPoint * ep, bool re
         ep->u.ipv4.addr = ntohl( addr.sin_addr.s_addr );
         ep->u.ipv4.port = ntohs( addr.sin_port );
         ep->type = epIPV4;
+        string_copy_measure ( ep -> ip_address, sizeof ep -> ip_address,
+                              inet_ntoa ( addr . sin_addr ) );
         return 0;
     }
 
@@ -427,19 +430,16 @@ static rc_t KSocketGetEndpoint ( const KSocket * self, KEndPoint * ep, bool remo
         {
             switch( self->type )
             {
-            case epIPV4: 
-                rc = KSocketGetEndpointV4( self, ep, remote ); 
+            case epIPV4:
+                rc = KSocketGetEndpointV4( self, ep, remote );
                 break;
-            case epIPV6: 
-                rc = KSocketGetEndpointV6( self, ep, remote ); 
+            case epIPV6:
+                rc = KSocketGetEndpointV6( self, ep, remote );
                 break;
-            default: 
+            default:
                 rc = RC ( rcNS, rcSocket, rcEvaluating, rcFunction, rcUnsupported );
                 break;
             }
-
-            string_copy_measure ( ep -> ip_address, sizeof ep -> ip_address,
-                                  self -> ip_address );
         }
     }
     return rc;
@@ -464,12 +464,12 @@ rc_t CC KSocketTimedRead ( const KSocket *self,
 {
     rc_t rc;
     int revents;
-    
+
     assert ( self != NULL );
     assert ( num_read != NULL );
 
     DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "%p: KSocketTimedRead(%d, %d)...\n", self, bsize, tm == NULL ? -1 : tm -> mS ) );
-    
+
     /* wait for socket to become readable */
     revents = socket_wait ( self -> fd
                             , POLLIN
@@ -513,7 +513,7 @@ rc_t CC KSocketTimedRead ( const KSocket *self,
             if ( ( getsockopt ( self -> fd, SOL_SOCKET, SO_ERROR, & optval, & optlen ) == 0 ) && optval > 0 )
             {
                 errno = optval;
-                DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "%p: KSocketTimedRead socket_wait/getsockopt returned '%!'\n", 
+                DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "%p: KSocketTimedRead socket_wait/getsockopt returned '%!'\n",
                                                             self, optval ) );
                 switch ( errno )
                 {
@@ -837,7 +837,63 @@ rc_t KSocketMakePath ( const char * name, char * buf, size_t buf_size )
 }
 
 static
-rc_t KSocketConnectIPv4 ( KSocket *self, const KEndPoint *from, const KEndPoint *to )
+rc_t
+TimedConnect( int socketFd, const struct sockaddr* ss, size_t ss_size, int32_t timeoutMs )
+{
+    int res;
+    /* set non-blocking mode */
+    int flag = fcntl ( socketFd, F_GETFL );
+    if ( flag == -1 )
+    {
+        DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): fcntl(F_GETFL) failed\n", socketFd ) );
+        return KSocketHandleConnectCall ( errno );
+    }
+    if ( fcntl ( socketFd, F_SETFL, flag | O_NONBLOCK ) == -1 )
+    {
+        DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): fcnl(F_SETFL) failed\n", socketFd ) );
+        return KSocketHandleConnectCall ( errno );
+    }
+
+    res = connect ( socketFd, ss, ss_size );
+    if ( res == 0 )
+    {
+        return 0;
+    }
+
+    if ( errno == EINPROGRESS )
+    {
+        int res = connect_wait( socketFd, timeoutMs );
+        if ( res > 0 )
+        {
+            return 0;
+        }
+
+        if ( res == 0 ) /* timed out */
+        {
+            DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): connect_wait() timed out\n", socketFd ) );
+            return KSocketHandleConnectCall ( ETIMEDOUT );
+        }
+
+        if ( errno == EINTR )
+        {
+            DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): connect_wait() interrupted\n", socketFd ) );
+            return RC ( rcNS, rcSocket, rcCreating, rcConnection, rcInterrupted );
+        }
+        else
+        {
+            DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): connect_wait() failed\n", socketFd ) );
+            return KSocketHandleConnectCall ( errno );
+        }
+    }
+    else
+    {
+        DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "TimedConnect(%d): connect() failed\n", socketFd ) );
+        return KSocketHandleConnectCall ( errno );
+    }
+}
+
+static
+rc_t KSocketConnectIPv4 ( KSocket *self, const KEndPoint *from, const KEndPoint *to, int32_t timeoutMs )
 {
     rc_t rc = 0;
 
@@ -863,22 +919,15 @@ rc_t KSocketConnectIPv4 ( KSocket *self, const KEndPoint *from, const KEndPoint
         /* bind */
         if ( bind ( self -> fd, ( struct sockaddr* ) & ss, sizeof ss ) != 0 )
             rc = KSocketHandleBindCall ( errno );
-                
+
         if ( rc == 0 )
         {
             ss . sin_port = htons ( to -> u . ipv4 . port );
             ss . sin_addr . s_addr = htonl ( to -> u . ipv4 . addr );
 
-            /* connect */
-            if ( connect ( self -> fd, ( struct sockaddr* ) & ss, sizeof ss ) != 0 )
-#warning "have an issue with EINTR here and other places"
-                rc = KSocketHandleConnectCall ( errno );
-            else
+            rc = TimedConnect ( self -> fd, ( struct sockaddr* ) & ss, sizeof ss, timeoutMs );
+            if ( rc == 0 )
             {
-                /* set non-blocking mode */
-                flag = fcntl ( self -> fd, F_GETFL );
-                fcntl ( self -> fd, F_SETFL, flag | O_NONBLOCK );
-
                 string_copy_measure ( self -> ip_address,
                     sizeof self -> ip_address, to -> ip_address );
 
@@ -898,7 +947,7 @@ rc_t KSocketConnectIPv4 ( KSocket *self, const KEndPoint *from, const KEndPoint
 
 
 static
-rc_t KSocketConnectIPv6 ( KSocket *self, const KEndPoint *from, const KEndPoint *to )
+rc_t KSocketConnectIPv6 ( KSocket *self, const KEndPoint *from, const KEndPoint *to, int32_t timeoutMs )
 {
     rc_t rc = 0;
     struct sockaddr_in6 ss_from, ss_to;
@@ -936,14 +985,9 @@ rc_t KSocketConnectIPv6 ( KSocket *self, const KEndPoint *from, const KEndPoint
 
         if ( rc == 0 )
         {
-            /* connect */
-            if ( connect ( self -> fd, ( struct sockaddr* ) & ss_to, sizeof ss_to ) != 0 )
-                rc = KSocketHandleConnectCall ( errno );
-            else
+            rc = TimedConnect ( self -> fd, ( struct sockaddr* ) & ss_to, sizeof ss_to, timeoutMs );
+            if ( rc == 0 )
             {
-                /* set non-blocking mode */
-                flag = fcntl ( self -> fd, F_GETFL );
-                fcntl ( self -> fd, F_SETFL, flag | O_NONBLOCK );
                 return 0;
             }
         }
@@ -952,7 +996,7 @@ rc_t KSocketConnectIPv6 ( KSocket *self, const KEndPoint *from, const KEndPoint
         close ( self -> fd );
         self -> fd = -1;
     }
-    
+
     DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET), ( "%p: KSocketConnectIPv6 failed - %R\n", self, rc ) );
 
     return rc;
@@ -980,7 +1024,7 @@ rc_t KSocketConnectIPC ( KSocket *self, const KEndPoint *to )
             rc = KSocketHandleConnectCall ( errno );
         else
             return 0;
-            
+
         /* dump socket */
         close ( self -> fd );
         self -> fd = -1;
@@ -1019,92 +1063,103 @@ KNS_EXTERN rc_t CC KNSManagerMakeRetryTimedConnection ( struct KNSManager const
                 conn -> write_timeout = writeMillis;
 
                 rc = KStreamInit ( & conn -> dad, ( const KStream_vt* ) & vtKSocket,
-                                   "KSocket", "", true, true );
-
-                /* prepare the timeout */
-                if ( rc == 0 )
-                    rc = TimeoutPrepare ( retryTimeout );
-
+                    "KSocket - RetryTimedConnection", to -> ip_address, true, true );
                 if ( rc == 0 )
                 {
-                    uint32_t retry;
-
-                    switch ( to -> type )
+                    /* prepare the timeout */
+                    rc = TimeoutPrepare ( retryTimeout );
+                    if ( rc == 0 )
                     {
+                        uint32_t retry;
 
-                    /* ensure the type is correct */
-                    case epIPV4:
-                    case epIPV6:
-                    case epIPC:
-
-                        /* a retry loop - retry upon a schedule for the alloted time */
-                        for ( retry = 0; ; ++ retry )
+                        switch ( to -> type )
                         {
-                            uint32_t remaining, delay;
 
-                            /* try to connect using appropriate protocol */
-                            conn -> type = to -> type;
-                            switch ( to -> type )
+                            /* ensure the type is correct */
+                        case epIPV4:
+                        case epIPV6:
+                        case epIPC:
+
+                            /* a retry loop - retry upon a schedule for the alloted time */
+                            for ( retry = 0; ; ++ retry )
                             {
-                            case epIPV4:
-                                rc = KSocketConnectIPv4 ( conn, from, to );
-                                break;
+                                uint32_t remaining, delay;
 
-                            case epIPV6:
-                                rc = KSocketConnectIPv6 ( conn, from, to );
-                                break;
+                                /* try to connect using appropriate protocol */
+                                conn -> type = to -> type;
+                                switch ( to -> type )
+                                {
+                                case epIPV4:
+                                    rc = KSocketConnectIPv4 ( conn, from, to, retryTimeout -> mS );
+                                    break;
 
-                            case epIPC:
-                                rc = KSocketConnectIPC ( conn, to );
-                                break;
+                                case epIPV6:
+                                    rc = KSocketConnectIPv6 ( conn, from, to, retryTimeout -> mS );
+                                    break;
+
+                                case epIPC:
+                                    rc = KSocketConnectIPC ( conn, to );
+                                    break;
+                                }
+
+                                /* if connection was successful, return socket */
+                                if ( rc == 0 )
+                                {
+                                    * out = conn;
+                                    return 0;
+                                }
+                                /* if was interrupted by Ctrl-C, return immediately */
+                                if ( rcConnection == GetRCObject ( rc ) && rcInterrupted == GetRCState ( rc ) )
+                                {
+                                    KSocketRelease ( conn );
+                                    * out = NULL;
+                                    return rc;
+                                }
+
+                                /* check time remaining on timeout ( if any ) */
+                                remaining = TimeoutRemaining ( retryTimeout );
+
+                                /* break out of loop if no time left */
+                                if ( remaining == 0 )
+                                    break;
+
+                                /* apply delay schedule */
+                                switch ( retry )
+                                {
+                                case 0:
+                                    /* try immediately */
+                                    continue;
+                                case 1:
+                                case 2:
+                                case 3:
+                                    /* wait for 100mS between tries */
+                                    delay = 100;
+                                    break;
+                                default:
+                                    /* wait for 250mS between tries */
+                                    delay = 250;
+                                }
+
+                                /* never wait for more than the remaining timeout */
+                                if ( delay > remaining )
+                                    delay = remaining;
+
+                                KSleepMs ( delay );
                             }
 
-                            /* if connection was successful, return socket */
-                            if ( rc == 0 )
-                            {
-                                * out = conn;
-                                return 0;
-                            }
+                            DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET),
+                                   ( "%p: KSocketConnect timed out\n", self ) );
+                            break;
 
-                            /* check time remaining on timeout ( if any ) */
-                            remaining = TimeoutRemaining ( retryTimeout );
-
-                            /* break out of loop if no time left */
-                            if ( remaining == 0 )
-                                break;
-
-                            /* apply delay schedule */
-                            switch ( retry )
-                            {
-                            case 0:
-                                /* try immediately */
-                                continue;
-                            case 1:
-                            case 2:
-                            case 3:
-                                /* wait for 100mS between tries */
-                                delay = 100;
-                                break;
-                            default:
-                                /* wait for 250mS between tries */
-                                delay = 250;
-                            }
-
-                            /* never wait for more than the remaining timeout */
-                            if ( delay > remaining )
-                                delay = remaining;
-
-                            KSleepMs ( delay );
+                        default:
+                            rc = RC ( rcNS, rcStream, rcConstructing, rcParam, rcIncorrect );
                         }
 
-                        DBGMSG(DBG_KNS, DBG_FLAG(DBG_KNS_SOCKET),
-                               ( "%p: KSocketConnect timed out\n", self ) ); 
-                       break;
+                    } /* if TimeoutPrepare () == 0 */
 
-                    default:
-                        rc = RC ( rcNS, rcStream, rcConstructing, rcParam, rcIncorrect );
-                    }
-                }
+                    KStreamWhack ( & conn -> dad, "KSocket" );
+
+                } /* if KStreamInit () == 0 */
 
                 free ( conn );
             }
@@ -1148,7 +1203,7 @@ rc_t KNSManagerMakeIPv6Listener ( KSocket *listener, const KEndPoint * ep )
            rc = KSocketHandleBindCall ( errno );
         else
             return 0;
-        
+
         close ( listener -> fd );
         listener -> fd = -1;
     }
@@ -1232,7 +1287,7 @@ rc_t KNSManagerMakeIPCListener ( KSocket *listener, const KEndPoint * ep )
 
 LIB_EXPORT rc_t CC KNSManagerMakeListener ( const KNSManager *self,
     KListener ** out, const KEndPoint * ep )
-{   
+{
     rc_t rc;
 
     if ( out == NULL )
@@ -1257,7 +1312,7 @@ LIB_EXPORT rc_t CC KNSManagerMakeListener ( const KNSManager *self,
                 listener -> write_timeout = self -> conn_write_timeout;
 
                 rc = KStreamInit ( & listener -> dad, ( const KStream_vt* ) & vtKSocket,
-                                   "KSocket", "", true, true );
+                    "KSocket - Listener", ep -> ip_address, true, true );
                 if ( rc == 0 )
                 {
                     listener -> type = ep -> type;
@@ -1308,7 +1363,7 @@ LIB_EXPORT rc_t CC KNSManagerMakeListener ( const KNSManager *self,
                                 break;
                             }
                         }
-                        
+
                         if ( listener -> path != NULL )
                             free ( ( void* ) listener -> path );
                     }
@@ -1427,13 +1482,13 @@ LIB_EXPORT rc_t CC KListenerAccept ( KListener *iself, struct KSocket **out )
                     new_socket -> remote_addr_valid = true;
 
                     rc = KStreamInit ( & new_socket -> dad, ( const KStream_vt* ) & vtKSocket,
-                                       "KSocket", "", true, true );
+                        "KSocket - Accept", "", true, true );
                     if ( rc == 0 )
                     {
                         * out = new_socket;
                         return 0;
                     }
-                    
+
                     free ( new_socket );
                 }
             }
