@@ -38,6 +38,8 @@
 #include <klib/rc.h>
 #include <sysalloc.h>
 
+#include <kfg/config.h>
+
 #include <stdlib.h>
 #include <string.h>
 #include <byteswap.h>
@@ -81,6 +83,8 @@ extern VTRANSFACT_DECL ( ALIGN_seq_restore_linkage_group );
 extern VTRANSFACT_DECL ( INSDC_SEQ_rand_4na_2na );
 extern VTRANSFACT_DECL ( INSDC_SRA_format_spot_name );
 extern VTRANSFACT_DECL ( INSDC_SRA_format_spot_name_no_coord );
+extern VTRANSFACT_DECL ( INSDC_SRA_read2spot_filter );
+extern VTRANSFACT_DECL ( INSDC_SRA_spot2read_filter );
 extern VTRANSFACT_DECL ( NCBI_SRA_ABI_tokenize_spot_name );
 extern VTRANSFACT_DECL ( NCBI_SRA_Helicos_tokenize_spot_name );
 extern VTRANSFACT_DECL ( NCBI_SRA_Illumina_tokenize_spot_name );
@@ -107,6 +111,7 @@ extern VTRANSFACT_DECL ( NCBI_SRA_lookup );
 extern VTRANSFACT_DECL ( NCBI_SRA_make_position );
 extern VTRANSFACT_DECL ( NCBI_SRA_make_read_desc );
 extern VTRANSFACT_DECL ( NCBI_SRA_make_spot_desc );
+extern VTRANSFACT_DECL ( NCBI_SRA_make_spot_filter );
 extern VTRANSFACT_DECL ( NCBI_SRA_normalize );
 #if HAVE_PREFIX_TREE_TO_NAME
 extern VTRANSFACT_DECL ( NCBI_SRA_prefix_tree_to_name );
@@ -121,11 +126,14 @@ extern VTRANSFACT_DECL ( NCBI_SRA_read_seg_from_readn );
 extern VTRANSFACT_DECL ( NCBI_SRA_rewrite_spot_name );
 extern VTRANSFACT_DECL ( NCBI_SRA_rotate );
 extern VTRANSFACT_DECL ( NCBI_SRA_swap );
+extern VTRANSFACT_DECL ( NCBI_SRA_syn_quality );
+
 extern VTRANSFACT_DECL ( NCBI_WGS_build_read_type );
 extern VTRANSFACT_DECL ( NCBI_WGS_build_scaffold_qual );
 extern VTRANSFACT_DECL ( NCBI_WGS_build_scaffold_read );
 extern VTRANSFACT_DECL ( NCBI_WGS_tokenize_nuc_accession );
 extern VTRANSFACT_DECL ( NCBI_WGS_tokenize_prot_accession );
+
 extern VTRANSFACT_DECL ( NCBI_align_clip );
 extern VTRANSFACT_DECL ( NCBI_align_clip_2 );
 extern VTRANSFACT_DECL ( NCBI_align_compress_quality );
@@ -172,6 +180,7 @@ extern VTRANSFACT_DECL ( NCBI_align_seq_construct_read );
 extern VTRANSFACT_DECL ( NCBI_align_template_len );
 extern VTRANSFACT_DECL ( NCBI_color_from_dna );
 extern VTRANSFACT_DECL ( NCBI_dna_from_color );
+extern VTRANSFACT_DECL ( NCBI_SRA_useRnaFlag );
 extern VTRANSFACT_DECL ( NCBI_fp_extend );
 extern VTRANSFACT_DECL ( NCBI_lower_case_tech_reads );
 extern VTRANSFACT_DECL ( NCBI_unpack );
@@ -230,24 +239,140 @@ extern bool CC NCBI_SRA_Illumina_untyped_1a ( struct KTable const *tbl, struct K
 extern bool CC NCBI_SRA_Illumina_untyped_1b ( struct KTable const *tbl, struct KMetadata const *meta );
 extern bool CC NCBI_SRA_ABI_untyped_1 ( struct KTable const *tbl, struct KMetadata const *meta );
 
-
-/* select is REALLY internal */
+/* these functions need something to fill in VFuncDesc */
 static
-rc_t CC select_func ( void *self, const VXformInfo *info, int64_t row_id,
+rc_t CC fake_stub_func ( void *self, const VXformInfo *info, int64_t row_id,
     VRowResult *rslt, uint32_t argc, const VRowData argv [] )
 {
+    assert(!"THIS FUNCTION IS NEVER TO BE CALLED");
+    abort();
     return 0;
 }
 
+/* select is REALLY internal */
 VTRANSFACT_BUILTIN_IMPL ( vdb_select, 1, 0, 0 ) ( const void *self,
     const VXfactInfo *info, VFuncDesc *rslt, const VFactoryParams *cp, const VFunctionParams *dp )
 {
     /* set function pointer to non-NULL */
-    rslt -> u . rf = select_func;
+    rslt -> u . rf = fake_stub_func;
     rslt -> variant = vftSelect;
     return 0;
 }
 
+#if THIS_IS_A_STUB_FOR_COPYPASTA
+/*
+function < type T >
+T passthru #1.0 ( T target )
+     = vdb:stub:function;
+ */
+/* all pass-through functions are REALLY internal */
+VTRANSFACT_BUILTIN_IMPL ( vdb_stub_function, 1, 0, 0 ) ( const void *self,
+    const VXfactInfo *info, VFuncDesc *rslt, const VFactoryParams *cp, const VFunctionParams *dp )
+{
+    bool shouldPassThru = false;
+
+    /* pass-through functions MUST have exactly one argument */
+    assert(dp->argc == 1);
+    
+    /* This is where to implement logic to determine if pass-through is wanted
+     */
+
+    /* from here to the end of the function stays the same */
+    if (shouldPassThru) {
+        /* set function pointer to non-NULL */
+        rslt -> u . rf = fake_stub_func;
+        
+        /* this is the magic that causes VFunctionProdRead to pass the Read
+         * message on to the first argument of this function */
+        rslt -> variant = vftPassThrough;
+        return 0;
+    }
+
+    /* some non-zero RC to signal that pass-through is NOT supposed to happen
+     * this will cause the schema to fall-through to the next rule or fail the
+     * production
+     */
+    return SILENT_RC(rcVDB, rcFunction, rcConstructing, rcFunction, rcIgnored);
+}
+#endif
+
+/* Pass-through function constructors should use this to prepare the result */
+static rc_t maybePass(bool const shouldPass, VFuncDesc *const rslt)
+{
+    if (shouldPass) {
+        rslt -> u . rf = fake_stub_func;
+        rslt -> variant = vftPassThrough;
+        return 0;
+    }
+    return SILENT_RC(rcVDB, rcFunction, rcConstructing, rcFunction, rcIgnored);
+}
+
+/* This function ALWAYS passes through
+function < type T >
+T passthru #1.0 ( T target )
+     = vdb:passthru;
+ */
+/* all pass-through functions are REALLY internal */
+VTRANSFACT_BUILTIN_IMPL ( vdb_passthru, 1, 0, 0 ) ( const void *self,
+    const VXfactInfo *info, VFuncDesc *rslt, const VFactoryParams *cp, const VFunctionParams *dp )
+{
+    return maybePass(true, rslt);
+}
+
+static bool compare_node_value(KConfigNode const *node, unsigned const len, char const *const value)
+{
+    char buffer[4096];
+    size_t num_read = 0, remaining = 0, offset = 0;
+
+    do {
+        KConfigNodeRead(node, offset, buffer, sizeof(buffer), &num_read, &remaining);
+        if (offset + num_read + remaining != len)
+            return false;
+        assert(offset + num_read <= len);
+        if (memcmp(buffer, value + offset, num_read) != 0)
+            return false;
+        offset += num_read;
+    } while (num_read > 0 && remaining > 0);
+    return offset == len;
+}
+
+static bool check_config_node(VFactoryParams const * const name_value)
+{
+    rc_t rc = 0;
+    bool result = false;
+    assert(name_value->argc == 2);
+    {
+        KConfig *cfg;
+        rc = KConfigMake(&cfg, NULL);
+        if (rc == 0) {
+            KConfigNode const *node;
+            rc = KConfigOpenNodeRead(cfg, &node, "%.*s"
+                                     , (int)name_value->argv[0].count
+                                     , name_value->argv[0].data.ascii);
+            if (rc == 0) {
+                result = compare_node_value(node
+                                            , name_value->argv[1].count
+                                            , name_value->argv[1].data.ascii);
+                KConfigNodeRelease(node);
+            }
+            KConfigRelease(cfg);
+        }
+    }
+    return result;
+}
+
+/*
+function < type T >
+T is_configuration_set #1.0 < ascii node, ascii value > ( T target )
+     = vdb:is_configuration_set;
+ */
+/* all pass-through functions are REALLY internal */
+VTRANSFACT_BUILTIN_IMPL ( vdb_is_configuration_set, 1, 0, 0 ) ( const void *self,
+    const VXfactInfo *info, VFuncDesc *rslt, const VFactoryParams *cp, const VFunctionParams *dp )
+{
+    return maybePass(check_config_node(cp), rslt);
+}
+
 /* temporary silly stuff
  */
 
@@ -437,6 +562,8 @@ rc_t VLinkerInitFactoriesRead ( VLinker *self,  KSymTable *tbl, const SchemaEnv
         { vdb_row_len, "vdb:row_len" },
         { vdb_fixed_row_len, "vdb:fixed_row_len" },
         { vdb_select, "vdb:select" },
+        { vdb_is_configuration_set, "vdb:is_configuration_set" },
+        { vdb_passthru, "vdb:passthru" },
         { vdb_compare, "vdb:compare" },
         { vdb_no_compare, "vdb:no_compare" },
         { vdb_range_validate, "vdb:range_validate" },
@@ -469,6 +596,8 @@ rc_t VLinkerInitFactoriesRead ( VLinker *self,  KSymTable *tbl, const SchemaEnv
         { INSDC_SEQ_rand_4na_2na, "INSDC:SEQ:rand_4na_2na" },
         { INSDC_SRA_format_spot_name, "INSDC:SRA:format_spot_name" },
         { INSDC_SRA_format_spot_name_no_coord, "INSDC:SRA:format_spot_name_no_coord" },
+        { INSDC_SRA_read2spot_filter, "INSDC:SRA:read2spot_filter" },
+        { INSDC_SRA_spot2read_filter, "INSDC:SRA:spot2read_filter" },
         { NCBI_SRA_ABI_tokenize_spot_name, "NCBI:SRA:ABI:tokenize_spot_name" },
         { NCBI_SRA_Helicos_tokenize_spot_name, "NCBI:SRA:Helicos:tokenize_spot_name" },
         { NCBI_SRA_Illumina_tokenize_spot_name, "NCBI:SRA:Illumina:tokenize_spot_name" },
@@ -497,6 +626,7 @@ rc_t VLinkerInitFactoriesRead ( VLinker *self,  KSymTable *tbl, const SchemaEnv
         { NCBI_SRA_make_position, "NCBI:SRA:make_position" },
         { NCBI_SRA_make_read_desc, "NCBI:SRA:make_read_desc" },
         { NCBI_SRA_make_spot_desc, "NCBI:SRA:make_spot_desc" },
+        { NCBI_SRA_make_spot_filter, "NCBI:SRA:make_spot_filter" },
         { NCBI_SRA_normalize, "NCBI:SRA:normalize" },
 #if HAVE_PREFIX_TREE_TO_NAME
         { NCBI_SRA_prefix_tree_to_name, "NCBI:SRA:prefix_tree_to_name" },
@@ -511,11 +641,14 @@ rc_t VLinkerInitFactoriesRead ( VLinker *self,  KSymTable *tbl, const SchemaEnv
         { NCBI_SRA_rewrite_spot_name, "NCBI:SRA:rewrite_spot_name" },
         { NCBI_SRA_rotate, "NCBI:SRA:rotate" },
         { NCBI_SRA_swap, "NCBI:SRA:swap" },
+        { NCBI_SRA_syn_quality, "NCBI:SRA:syn_quality" },
+
         { NCBI_WGS_build_read_type, "NCBI:WGS:build_read_type" },
         { NCBI_WGS_build_scaffold_qual, "NCBI:WGS:build_scaffold_qual" },
         { NCBI_WGS_build_scaffold_read, "NCBI:WGS:build_scaffold_read" },
         { NCBI_WGS_tokenize_nuc_accession, "NCBI:WGS:tokenize_nuc_accession" },
         { NCBI_WGS_tokenize_prot_accession, "NCBI:WGS:tokenize_prot_accession" },
+
         { NCBI_align_clip, "NCBI:align:clip" },
         { NCBI_align_clip_2, "NCBI:align:clip_2" },
         { NCBI_align_compress_quality, "NCBI:align:compress_quality" },
@@ -562,6 +695,7 @@ rc_t VLinkerInitFactoriesRead ( VLinker *self,  KSymTable *tbl, const SchemaEnv
         { NCBI_align_template_len, "NCBI:align:template_len" },
         { NCBI_color_from_dna, "NCBI:color_from_dna" },
         { NCBI_dna_from_color, "NCBI:dna_from_color" },
+        { NCBI_SRA_useRnaFlag, "NCBI:SRA:useRnaFlag" },
         { NCBI_fp_extend, "NCBI:fp_extend" },
         { NCBI_lower_case_tech_reads, "NCBI:lower_case_tech_reads" },
         { NCBI_unpack, "NCBI:unpack" },
