@@ -27,6 +27,8 @@
 #ifndef _h_resolver_priv_
 #define _h_resolver_priv_
 
+#include <klib/text.h> /* String */
+
 #ifndef _h_vfs_resolver_
 #include <vfs/resolver.h>
 #endif
@@ -35,6 +37,7 @@
 extern "C" {
 #endif
 
+#define DEFAULT_PROTOCOLS eProtocolHttpHttps
 
 /*--------------------------------------------------------------------------
  * KConfig Repository Structure
@@ -136,14 +139,16 @@ extern "C" {
 #define rcResolver   rcTree
 
 struct KDataBuffer;
+struct KNgcObj;
 struct KNSManager;
 struct String;
+struct VResolverAccToken;
 struct VResolverAlg;
 
-void VFSManagerSetNameResolverVersion3_0(void);
 
 rc_t VPathCheckFromNamesCGI(const struct VPath *path,
-    const struct String *ticket, const struct VPath **mapping);
+    const struct String *ticket, int64_t projectId,
+    const struct VPath **mapping);
 
 
 /*--------------------------------------------------------------------------
@@ -162,6 +167,7 @@ typedef enum
     appNANNOT,
     appNAKMER,
     appSRAPileup,
+    appSRARealign,
     appCount
 } VResolverAppID;
 
@@ -169,11 +175,16 @@ typedef enum
 {
     algCGI,
     algFlat,
+    algFlatAD,
+    algWithExtFlat,
+    algAD,    /* Accession as Directory */
+    algSRAAD,    /* Accession as Directory for SRA */
     algSRAFlat,
     algSRA1024,
     algSRA1000,
     algFUSE1000,
     algREFSEQ,
+    algREFSEQAD, /* Accession as Directory for Refseq*/
     algWGS2,                /* ordered to be of higher precedence than algWGS */
     algWGS,
     algWGSFlat,
@@ -196,6 +207,9 @@ typedef enum
     algUnknown
 } VResolverAlgID;
 
+#define versSDL2 1
+typedef uint8_t VERSNS;
+
 rc_t VResolverAlgMake(struct VResolverAlg **alg, const struct String *root,
      VResolverAppID app_id, VResolverAlgID alg_id, bool protctd, bool disabled);
 
@@ -215,7 +229,7 @@ rc_t VResolverAlgParseResolverCGIResponse_3_0(const char *start,
 rc_t VResolverAlgRemoteProtectedResolve( const struct VResolverAlg *self,
     const struct KNSManager *kns, VRemoteProtocols protocols,
     const struct String *acc, const struct VPath **path,
-    const struct VPath **mapping, bool legacy_wgs_refseq);
+    const struct VPath **mapping, bool legacy_wgs_refseq, const char * version);
 
 /** get projectId ( valid for protected user repository ) */
 rc_t VResolverGetProjectId ( const VResolver * self, uint32_t * projectId );
@@ -232,11 +246,34 @@ rc_t VResolverGetProjectId ( const VResolver * self, uint32_t * projectId );
 rc_t VResolverRemoteResolve ( const VResolver *self,
     VRemoteProtocols protocols, const struct String * accession,
     const struct VPath ** path, const struct VPath **mapping,
-    const struct KFile ** opt_file_rtn, bool refseq_ctx, bool is_oid );
+    const struct KFile ** opt_file_rtn, bool refseq_ctx, bool is_oid, const char * version );
 
+/* version of name service protocol */
+rc_t VResolverSetVersion ( VResolver *self, const char * version );
+
+/* resolve oid->file mapping inside of VFS
+  resolve (resolve oid<->name mapping in resolver):
+   0: default VResolver's behavior
+   1: resolve
+   2: don't resolve */
+rc_t VResolverResolveName ( VResolver *self, int resolve );
+
+bool VResolverResolveToAd(const VResolver *self);
+
+/*rc_t VFSManagerMakeDbgapResolver(const struct VFSManager * self,
+    VResolver ** new_resolver, const struct KConfig * cfg,
+    const struct KNgcObj * ngc);*/
+
+/* default behavior to resolve oid->file mapping inside of VFS */
+#define DEFAULT_RESOVE_OID_NAME true
 
 void KConfigReadRemoteProtocols ( struct KConfig const * self, VRemoteProtocols * remote_protos );
 
+VResolverAppID get_accession_app(const String * accession, bool refseq_ctx,
+    struct VResolverAccToken *tok, bool *legacy_wgs_refseq,
+    bool resolveAllAccToCache, bool * forDirAdjusted,
+    const String * parentAcc, int64_t projectId);
+
 #ifdef __cplusplus
 }
 #endif
