@@ -25,226 +25,47 @@
 * Unit tests for HTTP interfaces
 */
 
+#include "HttpFixture.hpp"
+
 #include <kapp/args.h> // Args
 
 #include <ktst/unit_test.hpp>
 
-#include <klib/debug.h> /* KDbgSetString */
-#include <klib/log.h>
 #include <klib/rc.h>
 #include <kfg/config.h>
+#include <kfg/kfg-priv.h>
 
 #include <kns/adapt.h> /* KStreamFromKFilePair */
 #include <kns/manager.h>
 #include <kns/kns-mgr-priv.h>
 #include <kns/http.h>
+#include <kns/stream.h>
+#include <kns/http-priv.h>
 
 #include <../libs/kns/mgr-priv.h>
 #include <../libs/kns/http-priv.h>
 
 #include <kfs/directory.h>
 #include <kfs/file.h>
-#include <kfs/defs.h>
+
+#include <vfs/manager.h>
+#include <vfs/manager-priv.h>
 
 #include <kproc/thread.h>
 
-#include <sysalloc.h>
-#include <stdexcept>
-#include <cstring>
-#include <list>
 #include <sstream>
 
-#define ALL
-
 static rc_t argsHandler ( int argc, char * argv [] );
 TEST_SUITE_WITH_ARGS_HANDLER ( HttpTestSuite, argsHandler );
 
 using namespace std;
 using namespace ncbi::NK;
 
-class TestStream;
-#define KSTREAM_IMPL TestStream
-#include <kns/impl.h>
-
 #define RELEASE(type, obj) do { rc_t rc2 = type##Release(obj); \
     if (rc2 != 0 && rc == 0) { rc = rc2; } obj = NULL; } while (false)
 
-
-class TestStream
-{
-public:
-    static KStream_vt_v1 vt;
-
-    static rc_t CC Whack ( KSTREAM_IMPL *self ) 
-    { 
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::Whack() called" << endl;
-        return 0; 
-    }
-    static rc_t CC Read ( const KSTREAM_IMPL *self, void *buffer, size_t bsize, size_t *num_read )
-    { 
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::Read() called" << endl;
-        * num_read = 0; 
-        return 0; 
-    }
-    static rc_t CC Write ( KSTREAM_IMPL *self, const void *buffer, size_t size, size_t *num_writ )
-    { 
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::Write() called" << endl;
-        * num_writ = size; 
-        return 0; 
-    }
-    static rc_t CC TimedRead ( const KSTREAM_IMPL *self, void *buffer, size_t bsize, size_t *num_read, struct timeout_t *tm )
-    { 
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::TimedRead() called" << endl;
-            
-        string response;
-        if ( m_responses.size()> 0)
-        {
-            response = m_responses.front();
-            m_responses.pop_front();
-        }
-        
-        if ( response.size() >= bsize )
-        {
-            memmove(buffer, response.c_str(), bsize);
-            * num_read = bsize; 
-            response = response.substr(bsize);
-        }
-        else
-        {
-            memmove(buffer, response.c_str(), response.size());
-            * num_read = response.size();
-            response.clear();
-        }
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::TimedRead returned \"" << string((const char*)buffer, * num_read) << "\"" << endl;
-        
-        return 0; 
-    }
-    static rc_t CC TimedWrite ( KSTREAM_IMPL *self, const void *buffer, size_t size, size_t *num_writ, struct timeout_t *tm )
-    { 
-        if ( TestEnv::verbosity == LogLevel::e_message )
-            cout << "TestStream::TimedWrite(\"" << string((const char*)buffer, size) << "\") called" << endl;
-        * num_writ = size; 
-        return 0; 
-    }
-
-    static void AddResponse ( const string& p_str, bool end_binary = false )
-    {
-        if (end_binary)
-            m_responses.push_back(p_str);
-        else
-            m_responses.push_back(std::string(p_str.c_str(), p_str.size() + 1));
-    }
-    
-    static list<string> m_responses;
-};
-
-KStream_vt_v1 TestStream::vt =
-{
-    1, 1,
-    TestStream::Whack,
-    TestStream::Read,
-    TestStream::Write,
-    TestStream::TimedRead,
-    TestStream::TimedWrite
-};
-
-list<string> TestStream::m_responses;
-
-class HttpFixture
-{
-public:
-    HttpFixture()
-    : m_mgr(0), m_file(0)
-    {
-        if ( KNSManagerMake ( & m_mgr ) != 0 )
-            throw logic_error ( "HttpFixture: KNSManagerMake failed" );
-                
-        if ( KStreamInit ( & m_stream, ( const KStream_vt* ) & TestStream::vt, "TestStream", "", true, true ) != 0 )
-            throw logic_error ( "HttpFixture: KStreamInit failed" );
-            
-        TestStream::m_responses.clear();
-    }
-    
-    ~HttpFixture()
-    {
-        if ( m_mgr && KNSManagerRelease ( m_mgr ) != 0 )
-            throw logic_error ( "HttpFixture::~HttpFixture KNSManagerRelease failed" );
-            
-        if ( m_file && KFileRelease ( m_file ) != 0 )
-            throw logic_error ( "HttpFixture::~HttpFixture KFileRelease failed" );
-            
-        if ( ! TestStream::m_responses.empty() )
-            throw logic_error ( "HttpFixture::~HttpFixture not all TestStream::m_responses have been consumed" );
-    }
-    
-    KConfig* MakeConfig( const char* name, const char* contents )
-    {
-        KDirectory* wd;
-        if ( KDirectoryNativeDir ( & wd ) != 0 )
-            throw logic_error("KfgFixture: KDirectoryNativeDir failed");
-            
-        {
-            KFile* file;    
-            if (KDirectoryCreateFile(wd, &file, true, 0664, kcmInit, name) != 0)
-                throw logic_error("MakeConfig: KDirectoryCreateFile failed");
-
-            size_t num_writ=0;
-            if (KFileWrite(file, 0, contents, strlen(contents), &num_writ) != 0)
-                throw logic_error("MakeConfig: KFileWrite failed");
-
-            if (KFileRelease(file) != 0)
-                throw logic_error("MakeConfig: KFileRelease failed");    
-        }
-        
-        KConfig* ret;
-        {
-            if (KConfigMake ( & ret, wd ) != 0) 
-                throw logic_error("MakeConfig: KConfigMake failed");        
-                
-            KFile* file;    
-            if (KDirectoryOpenFileRead(wd, (const KFile**)&file, name) != 0)
-                throw logic_error("MakeConfig: KDirectoryOpenFileRead failed");
-            
-            if (KConfigLoadFile ( ret, name, file) != 0)
-                throw logic_error("MakeConfig: KConfigLoadFile failed");
-
-            if (KFileRelease(file) != 0)
-                throw logic_error("MakeConfig: KFileRelease failed");
-        }
-        
-        if (KDirectoryRemove(wd, true, name) != 0)
-            throw logic_error("MakeConfig: KDirectoryRemove failed");
-        if (KDirectoryRelease(wd) != 0)
-            throw logic_error("MakeConfig: KDirectoryRelease failed");
-        
-        return ret;
-    }
-    
-    static struct KStream * Reconnect ()
-    {   
-        return & m_stream; 
-    }
-    
-    static string MakeURL(const char* base)
-    {
-        return string("http://") + base + ".com/";
-    }    
-    
-    KNSManager* m_mgr;
-    static KStream m_stream;
-    KFile* m_file;
-};
-
-KStream HttpFixture::m_stream;
-
-#ifdef ALL
 //////////////////////////
-// Regular HTTP 
+// Regular HTTP
 FIXTURE_TEST_CASE(Http_Make, HttpFixture)
 {
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n");
@@ -252,7 +73,6 @@ FIXTURE_TEST_CASE(Http_Make, HttpFixture)
     REQUIRE_NOT_NULL ( m_file ) ;
 }
 
-#if 1
 /*FIXME: 100 used to be retried regardless of whether URL is reliable, now it is not, so the test fails */
 FIXTURE_TEST_CASE(Http_Make_Continue_100_Retry, HttpFixture)
 {
@@ -262,7 +82,6 @@ FIXTURE_TEST_CASE(Http_Make_Continue_100_Retry, HttpFixture)
     REQUIRE_RC ( KNSManagerMakeHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str() ) );
     REQUIRE_NOT_NULL ( m_file ) ;
 }
-#endif
 
 FIXTURE_TEST_CASE(Http_Make_500_Fail, HttpFixture)
 {   // a regular Http client does not retry
@@ -291,6 +110,32 @@ FIXTURE_TEST_CASE(Http_Read, HttpFixture)
     REQUIRE_EQ( string ( "content" ), string ( buf, num_read ) );
 }
 
+FIXTURE_TEST_CASE(VDB_3661, HttpFixture)
+{
+    const KFile * file = NULL;
+    REQUIRE_RC ( KNSManagerMakeHttpFile ( m_mgr, & file, NULL, 0x01010000,
+       "http://public_docs.crg.es/rguigo/Papers/2017_lagarde-uszczynska_CLS/data/trackHub//dataFiles/hsAll_Cap1_Brain_hiSeq.bam"
+      ) );
+
+    uint64_t size = 0;
+    REQUIRE_RC ( KFileSize ( file, & size ) );
+    size = std::min(size, decltype(size)(4 * 1024 * 1024));
+
+    void * buffer = malloc ( size );
+    REQUIRE_NOT_NULL ( buffer );
+
+    size_t num_read = 0;
+
+    // read small chunk; should succeed
+    size_t bsize = size;
+    REQUIRE_RC ( KFileRead ( file, 0, buffer, bsize, & num_read ) );
+    REQUIRE_EQ ( num_read, bsize );
+
+    free ( buffer );
+
+    REQUIRE_RC ( KFileRelease ( file ) );
+}
+
 struct ReadThreadData
 {
     int tid;
@@ -419,20 +264,6 @@ FIXTURE_TEST_CASE(Http_Read_Multi_User, HttpFixture)
 
 }
 
-FIXTURE_TEST_CASE(HttpRequest_POST_NoParams, HttpFixture)
-{   // Bug: KClientHttpRequestPOST crashed if request had no parameters
-    KClientHttpRequest *req;
-    KNSManagerMakeClientRequest ( m_mgr, &req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
-
-    KClientHttpResult *rslt;
-    TestStream::AddResponse("HTTP/1.1 200 OK\r\n");
-    REQUIRE_RC ( KClientHttpRequestPOST ( req, & rslt ) );
-    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
-
-    REQUIRE_RC ( KClientHttpRequestRelease ( req ) );
-}
-
-
 //////////////////////////
 // HttpRetrySpecs
 
@@ -555,7 +386,7 @@ public:
     ~RetrierFixture()
     {
         if ( KHttpRetrierDestroy ( & m_retrier ) != 0 )
-            throw logic_error ( "RetrierFixture::~RetrierFixture KHttpRetrierDestroy failed" );
+            cerr << "RetrierFixture::~RetrierFixture KHttpRetrierDestroy failed" << endl;
     }
 
     void Configure ( const char* kfg_name, const char* kfg_content, uint8_t max_retries = MaxRetries, uint32_t max_total_wait = MaxTotalWait )
@@ -681,9 +512,10 @@ FIXTURE_TEST_CASE(HttpRetrier_Retry_OpenEnded_MaxRetries, RetrierFixture)
 FIXTURE_TEST_CASE(HttpReliable_Make, HttpFixture)
 {
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n");
-    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
     REQUIRE_NOT_NULL ( m_file ) ;
 }
+
 #if 0
 /* 100 used to be retried regardless, now it is not, so the test fails */
 FIXTURE_TEST_CASE(HttpReliable_Make_Continue_100_Retry, HttpFixture)
@@ -691,7 +523,7 @@ FIXTURE_TEST_CASE(HttpReliable_Make_Continue_100_Retry, HttpFixture)
     TestStream::AddResponse("HTTP/1.1 100 continue\r\n");
     TestStream::AddResponse("HTTP/1.1 100 continue\r\n");
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n");
-    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
     REQUIRE_NOT_NULL ( m_file ) ;
 }
 #endif
@@ -700,7 +532,7 @@ FIXTURE_TEST_CASE(HttpReliable_Make_5xx_retry, HttpFixture)
 {   // use default configuration for 5xx to be retried
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n");
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n");
-    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
     REQUIRE_NOT_NULL ( m_file ) ;
 }
 
@@ -708,7 +540,7 @@ FIXTURE_TEST_CASE(HttpReliable_Make_500_Fail, RetrierFixture)
 {
     Configure ( GetName(), "http/reliable/500=\"\"\n"); // do not retry 500
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n");
-    REQUIRE_RC_FAIL ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC_FAIL ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
 }
 
 FIXTURE_TEST_CASE(HttpReliable_Make_500_Retry, RetrierFixture)
@@ -716,7 +548,7 @@ FIXTURE_TEST_CASE(HttpReliable_Make_500_Retry, RetrierFixture)
     Configure ( GetName(), "http/reliable/500=\"0+\"\n" "http/reliable/5xx=\"\"\n"); // do not retry 5xx, retry 500
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n");
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n");
-    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
     REQUIRE_NOT_NULL ( m_file ) ;
 }
 
@@ -725,7 +557,7 @@ FIXTURE_TEST_CASE(HttpReliable_Make_500_TooManyRetries, RetrierFixture)
     Configure ( GetName(), "http/reliable/500=\"0\"\n" "http/reliable/5xx=\"\"\n"); // do not retry 5xx, retry 500 once
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n");
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n");
-    REQUIRE_RC_FAIL ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC_FAIL ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
 }
 
 #ifdef _DEBUGGING
@@ -734,7 +566,7 @@ FIXTURE_TEST_CASE(HttpReliable_Read_Retry, HttpFixture)
     SetClientHttpReopenCallback ( Reconnect ); // this hook is only available in DEBUG mode
 
     TestStream::AddResponse("HTTP/1.1 200 OK\r\nAccept-Ranges: bytes\r\nContent-Length: 7\r\n"); // response to HEAD
-    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, MakeURL(GetName()).c_str()  ) );
+    REQUIRE_RC ( KNSManagerMakeReliableHttpFile( m_mgr, ( const KFile** ) &  m_file, & m_stream, 0x01010000, true, false, false, MakeURL(GetName()).c_str() ) );
     char buf[1024];
     size_t num_read;
     TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\n"); // response to GET
@@ -753,81 +585,6 @@ FIXTURE_TEST_CASE(HttpReliable_Read_Retry, HttpFixture)
 }
 #endif
 
-//////////////////////////
-// Reliable HTTP request
-FIXTURE_TEST_CASE(HttpReliableRequest_Make, HttpFixture)
-{
-    KClientHttpRequest *req;
-    KNSManagerMakeReliableClientRequest ( m_mgr, &req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
-    REQUIRE_NOT_NULL ( req ) ;
-    REQUIRE_RC ( KClientHttpRequestRelease ( req ) );
-}
-
-FIXTURE_TEST_CASE(HttpReliableRequest_POST_5xx_retry, HttpFixture)
-{   // use default configuration for 5xx to be retried
-    KClientHttpRequest *req;
-    KNSManagerMakeReliableClientRequest ( m_mgr, &req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
-
-    TestStream::AddResponse("HTTP/1.1 500 Internal Server Error\r\nContent-Length: 0\r\n"); // response to GET
-    TestStream::AddResponse("HTTP/1.1 200 OK\r\n");
-
-    KClientHttpResult *rslt;
-    REQUIRE_RC ( KClientHttpRequestPOST ( req, & rslt ) );
-
-    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
-    REQUIRE_RC ( KClientHttpRequestRelease ( req ) );
-}
-
-#endif
-
-#ifdef ALL
-/* VDB-3059: KHttpRequestPOST generates incorrect Content-Length after retry :
- it makes web server to return 400 Bad Request */
-TEST_CASE(ContentLength) {
-    rc_t rc = 0;
-    KNSManager * kns = NULL;
-    REQUIRE_RC ( KNSManagerMake ( & kns ) );
-
-    uint32_t code = 0;
-    KHttpRequest * req = NULL;
-    KHttpResult * rslt = NULL;
-    KStream * response = NULL;
-
-    /* calling good cgi returns 200 and resolved path */
-    REQUIRE_RC ( KNSManagerMakeReliableClientRequest ( kns, & req, 0x01000000,
-        NULL, "https://www.ncbi.nlm.nih.gov/Traces/names/names.fcgi" ) ); 
-    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "acc=AAAB01" ) );
-    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "accept-proto=https" ) );
-    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "version=1.2" ) );
-    REQUIRE_RC ( KHttpRequestPOST ( req, & rslt ) );
-    REQUIRE_RC ( KClientHttpResultStatus ( rslt, & code, NULL, 0, NULL ) );
-    REQUIRE_EQ ( code, 200u );
-    REQUIRE_RC ( KHttpResultGetInputStream ( rslt, & response ) );
-    char buffer [ 512 ] = "";
-    size_t num_read = 0;
-    REQUIRE_RC (KStreamRead( response, buffer, sizeof buffer - 1,  &num_read ));
-    REQUIRE_LT ( num_read, sizeof buffer );
-    buffer [ num_read ] = '\0';
-    REQUIRE_EQ ( string ( buffer + num_read - 7 ), string ( "200|ok\n" ) );
-    RELEASE ( KStream, response );
-    RELEASE ( KHttpResult, rslt );
-    RELEASE ( KHttpRequest, req );
-
-    /* calling non-existing cgi returns 404 */
-    REQUIRE_RC ( KNSManagerMakeReliableClientRequest ( kns, & req, 0x01000000,
-        NULL, "https://www.ncbi.nlm.nih.gov/Traces/names/bad.cgi" ) ); 
-    REQUIRE_RC ( KHttpRequestAddPostParam ( req, "acc=AAAB01" ) );
-    REQUIRE_RC ( KHttpRequestPOST ( req, & rslt ) );
-    REQUIRE_RC ( KClientHttpResultStatus ( rslt, & code, NULL, 0, NULL ) );
-    REQUIRE_EQ ( code, 404u );
-    RELEASE ( KHttpResult, rslt );
-    RELEASE ( KHttpRequest, req );
-
-    RELEASE ( KNSManager, kns );
-    REQUIRE_RC ( rc );
-}
-#endif
-
 struct NV {
     String AcceptRanges;
     const string bytes;
@@ -849,7 +606,7 @@ TEST_CASE ( RepeatedHeader ) {
     REQUIRE_RC ( KDirectoryNativeDir ( & dir ) );
 
     const KFile * f = NULL;
-    REQUIRE_RC ( KDirectoryOpenFileRead ( dir, & f, "double_header.txt" ) );
+    REQUIRE_RC ( KDirectoryOpenFileRead ( dir, & f, "data/double_header.txt" ) );
 
     KNSManager * mgr = NULL;
     REQUIRE_RC ( KNSManagerMake ( & mgr ) );
@@ -888,7 +645,7 @@ TEST_CASE ( RepeatedHeader ) {
     string via ( "1.0 fred,1.1 example.com (Apache/1.1)" );
 
     for ( const KHttpHeader * hdr = reinterpret_cast
-                < const KHttpHeader * > ( BSTreeFirst ( & hdrs ) ); 
+                < const KHttpHeader * > ( BSTreeFirst ( & hdrs ) );
           hdr != NULL;
           hdr = reinterpret_cast
                 < const KHttpHeader * > ( BSTNodeNext ( & hdr -> dad ) )
@@ -960,9 +717,9 @@ TEST_CASE ( TestKClientHttpResultTestHeaderValue ) {
 }
 
 TEST_CASE ( AllowAllCertificates )
-{
+{   // as of
     rc_t rc = 0;
-    
+
     KNSManager * mgr = NULL;
     REQUIRE_RC ( KNSManagerMake ( & mgr ) );
 
@@ -971,30 +728,26 @@ TEST_CASE ( AllowAllCertificates )
     REQUIRE_RC ( KNSManagerGetAllowAllCerts ( mgr, & allow_all_certs ) );
 
     // ensure that manager is NOT allowing, i.e. default behavior
+    // as of 7-01-2019, this function is a no-op, so the connection will succeed with
+    // or without this call. NOTE: on WINDOWS, it still works as before!
     REQUIRE_RC ( KNSManagerSetAllowAllCerts ( mgr, false ) );
 
     // create a connection to something that normally fails; it should fail
     String host;
     CONST_STRING ( & host, "www.google.com" );
 
-    // capture log level
-    KLogLevel log_level = KLogLevelGet ();
-    
-    // set log level to practically silent
-    KLogLevelSet ( 0 );
-    
     KClientHttp * https = NULL;
-    REQUIRE ( KNSManagerMakeClientHttps
-              ( mgr, & https, NULL, 0x01010000, & host, 443 ) != 0 );
-    RELEASE ( KClientHttp, https );
-
-    // restore log level
-    KLogLevelSet ( log_level );
+#if WINDOWS
+    REQUIRE_RC_FAIL( KNSManagerMakeClientHttps( mgr, &https, NULL, 0x01010000, &host, 443 ) );
+#else
+    REQUIRE_RC ( KNSManagerMakeClientHttps( mgr, &https, NULL, 0x01010000, &host, 443 ) );
+#endif
+    RELEASE(KClientHttp, https);
 
     // tell manager to allow all certs
     REQUIRE_RC ( KNSManagerSetAllowAllCerts ( mgr, true ) );
 
-    // repeat connection to something that normally fails; it should succeed
+    // repeat connection to something that used to fail; it should succeed
     REQUIRE_RC ( KNSManagerMakeClientHttps
               ( mgr, & https, NULL, 0x01010000, & host, 443 ) );
     RELEASE ( KClientHttp, https );
@@ -1003,6 +756,88 @@ TEST_CASE ( AllowAllCertificates )
     REQUIRE_RC ( KNSManagerSetAllowAllCerts ( mgr, allow_all_certs ) );
 }
 
+// KClientHttpResult
+
+FIXTURE_TEST_CASE( KClientHttpResult_Size_HEAD, HttpFixture)
+{
+    KNSManagerMakeClientRequest ( m_mgr, &m_req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
+
+    TestStream::AddResponse(
+        "HTTP/1.1 200 \r\n"
+        "content-length: 2975717 \r\n"
+        "\r\n");
+
+    KClientHttpResult *rslt;
+    REQUIRE_RC ( KClientHttpRequestHEAD ( m_req, & rslt ) );
+    uint64_t size = 0;
+    REQUIRE ( KClientHttpResultSize ( rslt, &size ) );
+    REQUIRE_EQ ( (uint64_t)2975717, size );
+
+    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
+}
+
+FIXTURE_TEST_CASE( KClientHttpResult_Size_RangedGET, HttpFixture)
+{
+    KNSManagerMakeClientRequest ( m_mgr, &m_req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
+    REQUIRE_RC ( KClientHttpRequestByteRange ( m_req, 0, 2 ) );
+
+    TestStream::AddResponse(
+        "HTTP/1.1 206 \r\n"
+        "content-length: 2\r\n"
+        "content-range: bytes 0-1/2975717        \r\n"  // if content-range is present, retrieve total from it, not content-length
+        "\r\n");
+
+    KClientHttpResult *rslt;
+    REQUIRE_RC ( KClientHttpRequestGET ( m_req, & rslt ) );
+    uint64_t size = 0;
+    REQUIRE ( KClientHttpResultSize ( rslt, &size ) );
+    REQUIRE_EQ ( (uint64_t)2975717, size );
+
+    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
+}
+
+FIXTURE_TEST_CASE( KClientHttpResult_Size_RangedPOST, HttpFixture)
+{
+    KNSManagerMakeClientRequest ( m_mgr, &m_req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
+    REQUIRE_RC ( KClientHttpRequestByteRange ( m_req, 0, 2 ) );
+
+    TestStream::AddResponse(
+        "HTTP/1.1 206 \r\n"
+        "content-length: 2\r\n"
+        "content-range: bytes 0-1/2975717        \r\n"  // if content-range is present, retrieve total from it, not content-length
+        "\r\n");
+
+    KClientHttpResult *rslt;
+    REQUIRE_RC ( KClientHttpRequestPOST ( m_req, & rslt ) );
+    uint64_t size = 0;
+    REQUIRE ( KClientHttpResultSize ( rslt, &size ) );
+    REQUIRE_EQ ( (uint64_t)2975717, size );
+
+    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
+}
+
+FIXTURE_TEST_CASE( KClientHttpResult_FormatMsg, HttpFixture)
+{
+    KNSManagerMakeClientRequest ( m_mgr, &m_req, 0x01010000, & m_stream, MakeURL(GetName()).c_str()  );
+    REQUIRE_RC ( KClientHttpRequestByteRange ( m_req, 0, 2 ) );
+
+    TestStream::AddResponse(
+        "HTTP/1.1 206 \r\n"
+        "content-length: 2\r\n"
+        "\r\n");
+    string expected =
+        "->HTTP/1.1 206 \n" // \r is gone
+        "->content-length: 2\r\n";
+
+    KClientHttpResult *rslt;
+    REQUIRE_RC ( KClientHttpRequestPOST ( m_req, & rslt ) );
+    KDataBuffer buffer;
+    REQUIRE_RC ( KDataBufferMake( & buffer, 8, 0 ) );
+    REQUIRE_RC ( KClientHttpResultFormatMsg ( rslt, & buffer, "->", "\n" ) );
+    REQUIRE_EQ ( expected, string ((char*)buffer.base) );
+    REQUIRE_RC ( KClientHttpResultRelease ( rslt ) );
+}
+
 //////////////////////////////////////////// Main
 
 static rc_t argsHandler ( int argc, char * argv [] ) {
@@ -1044,7 +879,7 @@ rc_t CC KMain ( int argc, char *argv [] )
 	// this makes messages from the test code appear
 	// (same as running the executable with "-l=message")
 	// TestEnv::verbosity = LogLevel::e_message;
-	
+
     rc_t rc=HttpTestSuite(argc, argv);
     return rc;
 }
