@@ -32,6 +32,8 @@
 
 #include <kdb/manager.h>
 
+#include <kfg/config.h> /* KConfigDisableUserSettings */
+
 #include <vdb/manager.h>
 #include <vdb/vdb-priv.h>
 
@@ -69,7 +71,7 @@ public:
         }
         NGS_C_Fixture :: Release ();
     }
-    
+
     void GetAlignment(uint64_t id)
     {
         stringstream str;
@@ -84,21 +86,21 @@ public:
                 throw logic_error ("premature end of iterator");
             if ( m_ctx -> rc != 0 )
                 throw logic_error ("NGS_AlignmentIteratorNext failed");
-                
+
             if (print)
                 cout << toString ( NGS_AlignmentGetAlignmentId ( m_align, m_ctx ), m_ctx, true ) << endl;
         }
     }
     void PrintAlignment ()
     {
-        cout << "id=" << toString ( NGS_AlignmentGetAlignmentId ( m_align, m_ctx ), m_ctx, true ) 
-             << " pos=" << NGS_AlignmentGetAlignmentPosition ( m_align, m_ctx ) 
-             << " len=" << NGS_AlignmentGetAlignmentLength ( m_align, m_ctx ) 
+        cout << "id=" << toString ( NGS_AlignmentGetAlignmentId ( m_align, m_ctx ), m_ctx, true )
+             << " pos=" << NGS_AlignmentGetAlignmentPosition ( m_align, m_ctx )
+             << " len=" << NGS_AlignmentGetAlignmentLength ( m_align, m_ctx )
              << ( NGS_AlignmentIsPrimary ( m_align, m_ctx ) ? " PRI" : " SEC" )
              << " mapq=" << NGS_AlignmentGetMappingQuality( m_align, m_ctx )
-             << endl;    
+             << endl;
     }
-    
+
     bool NextId (const string& p_expected)
     {
         if ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) || m_ctx -> rc != 0 )
@@ -114,7 +116,7 @@ public:
         }
         return m_ctx -> rc == 0;
     }
-    
+
     bool VerifyOrder()
     {
         uint64_t prevPos = 0;
@@ -132,7 +134,7 @@ public:
                 PrintAlignment();
                 return false;
             }
-            if ( prevPos == newPos ) 
+            if ( prevPos == newPos )
             {
                 if ( prevLen < newLen )
                 {
@@ -163,7 +165,7 @@ public:
         }
         return true;
     }
-    
+
     NGS_Alignment*      m_align;
 };
 
@@ -171,52 +173,54 @@ public:
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_NoAccessBeforeNext, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_PrimaryOnly, "supercont2.1" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false ); 
 
-    REQUIRE_NULL ( NGS_AlignmentGetAlignmentId ( m_align, ctx ) ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false );
+
+    REQUIRE_NULL ( NGS_AlignmentGetAlignmentId ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetReferenceSpec ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetReferenceSpec ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetMappingQuality ( m_align, ctx ); 
+    NGS_AlignmentGetMappingQuality ( m_align, ctx );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetReadGroup ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetReadGroup ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetReadId ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetReadId ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetClippedFragmentBases ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetClippedFragmentBases ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetClippedFragmentQualities ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetClippedFragmentQualities ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    NGS_AlignmentIsPrimary ( m_align, ctx ); 
+    NGS_AlignmentIsPrimary ( m_align, ctx );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetAlignmentPosition ( m_align, ctx ); 
+    NGS_AlignmentGetAlignmentPosition ( m_align, ctx );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetAlignmentLength ( m_align, ctx ); 
+    NGS_AlignmentGetAlignmentLength ( m_align, ctx );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetIsReversedOrientation ( m_align, ctx ); 
+    NGS_AlignmentGetIsReversedOrientation ( m_align, ctx );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetSoftClip ( m_align, ctx, true ); 
+    NGS_AlignmentGetSoftClip ( m_align, ctx, true );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetTemplateLength ( m_align, ctx ); 
+    NGS_AlignmentGetTemplateLength ( m_align, ctx );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetShortCigar ( m_align, ctx, true ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetShortCigar ( m_align, ctx, true ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetLongCigar ( m_align, ctx, true ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetLongCigar ( m_align, ctx, true ) );
+    REQUIRE_FAILED ();
+    NGS_AlignmentIsFirst ( m_align, ctx );
     REQUIRE_FAILED ();
 
-    REQUIRE ( ! NGS_AlignmentHasMate ( m_align, ctx ) ); 
+    REQUIRE ( ! NGS_AlignmentHasMate ( m_align, ctx ) );
     REQUIRE ( ! FAILED () ); /* HasMate does not throw */
-    
-    REQUIRE_NULL ( NGS_AlignmentGetMateAlignmentId ( m_align, ctx ) ); 
+
+    REQUIRE_NULL ( NGS_AlignmentGetMateAlignmentId ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetMateAlignment ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetMateAlignment ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    REQUIRE_NULL ( NGS_AlignmentGetMateReferenceSpec ( m_align, ctx ) ); 
+    REQUIRE_NULL ( NGS_AlignmentGetMateReferenceSpec ( m_align, ctx ) );
     REQUIRE_FAILED ();
-    NGS_AlignmentGetMateIsReversedOrientation ( m_align, ctx ); 
-    REQUIRE_FAILED (); 
-    
+    NGS_AlignmentGetMateIsReversedOrientation ( m_align, ctx );
+    REQUIRE_FAILED ();
+
     // fragment functions
     REQUIRE_NULL ( NGS_FragmentGetId ( (NGS_Fragment*)m_align, ctx ) );
     REQUIRE_FAILED ();
@@ -224,96 +228,99 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_NoAccessBeforeNext, CSRA1_Fixture)
     REQUIRE_FAILED ();
     REQUIRE_NULL ( NGS_FragmentGetQualities ( (NGS_Fragment*)m_align, ctx, 2, 5 ) );
     REQUIRE_FAILED ();
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_AccessAfterNext, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_PrimaryOnly, "supercont2.1" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false ); 
+
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false );
     REQUIRE ( NGS_AlignmentIteratorNext ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
 
-    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".PA.1", NGS_AlignmentGetAlignmentId ( m_align, ctx ) ); 
+    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".PA.1", NGS_AlignmentGetAlignmentId ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
 
-    REQUIRE_STRING ( "supercont2.1", NGS_AlignmentGetReferenceSpec ( m_align, ctx ) ); 
+    REQUIRE_STRING ( "supercont2.1", NGS_AlignmentGetReferenceSpec ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_EQ ( 60, NGS_AlignmentGetMappingQuality ( m_align, ctx ) ); 
+
+    REQUIRE_EQ ( 60, NGS_AlignmentGetMappingQuality ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "C1ELY.6", NGS_AlignmentGetReadGroup ( m_align, ctx ) ); 
+
+    REQUIRE_STRING ( "C1ELY.6", NGS_AlignmentGetReadGroup ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".R.1", NGS_AlignmentGetReadId ( m_align, ctx ) ); 
+
+    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".R.1", NGS_AlignmentGetReadId ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "ACTCGACATTCTGCCTTCGACCTATCTTTCTCCTCTCCCAGTCATCGCCCAGTAGAATTACCAGGCAATGAACCAGGGCCTTCCATCCCAACGGCACAGCA", 
+
+    REQUIRE_STRING ( "ACTCGACATTCTGCCTTCGACCTATCTTTCTCCTCTCCCAGTCATCGCCCAGTAGAATTACCAGGCAATGAACCAGGGCCTTCCATCCCAACGGCACAGCA",
                      NGS_AlignmentGetClippedFragmentBases ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "@@CDDBDFFBFHFIEEFGIGGHIEHIGIGGFGEGAFDHIIIIIGGGDFHII;=BF@FEHGIEEH?AHHFHFFFFDC5'5=?CC?ADCD@AC??9BDDCDB<", 
+
+    REQUIRE_STRING ( "@@CDDBDFFBFHFIEEFGIGGHIEHIGIGGFGEGAFDHIIIIIGGGDFHII;=BF@FEHGIEEH?AHHFHFFFFDC5'5=?CC?ADCD@AC??9BDDCDB<",
                      NGS_AlignmentGetClippedFragmentQualities ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE ( NGS_AlignmentIsPrimary ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_EQ ( (int64_t)85, NGS_AlignmentGetAlignmentPosition ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_EQ ( (uint64_t)101, NGS_AlignmentGetAlignmentLength ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE ( ! NGS_AlignmentGetIsReversedOrientation ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_EQ ( (int)0, NGS_AlignmentGetSoftClip ( m_align, ctx, true ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_EQ ( (uint64_t)201, NGS_AlignmentGetTemplateLength ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "101M", NGS_AlignmentGetShortCigar ( m_align, ctx, true ) ); 
-    REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "13=1X61=1X6=1X18=", NGS_AlignmentGetLongCigar ( m_align, ctx, true ) ); 
+
+    REQUIRE ( NGS_AlignmentIsPrimary ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
 
-    REQUIRE ( NGS_AlignmentHasMate ( m_align, ctx ) ); 
-    REQUIRE ( ! FAILED () ); 
-    
-    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".PA.2", NGS_AlignmentGetMateAlignmentId ( m_align, ctx ) ); 
+    REQUIRE_EQ ( (int64_t)85, NGS_AlignmentGetAlignmentPosition ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
+
+    REQUIRE_EQ ( (uint64_t)101, NGS_AlignmentGetAlignmentLength ( m_align, ctx ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE ( ! NGS_AlignmentGetIsReversedOrientation ( m_align, ctx ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE_EQ ( (int)0, NGS_AlignmentGetSoftClip ( m_align, ctx, true ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE_EQ ( (uint64_t)201, NGS_AlignmentGetTemplateLength ( m_align, ctx ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE_STRING ( "101M", NGS_AlignmentGetShortCigar ( m_align, ctx, true ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE_STRING ( "13=1X61=1X6=1X18=", NGS_AlignmentGetLongCigar ( m_align, ctx, true ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE ( NGS_AlignmentHasMate ( m_align, ctx ) );
+    REQUIRE ( ! FAILED () );
+
+    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".PA.2", NGS_AlignmentGetMateAlignmentId ( m_align, ctx ) );
+    REQUIRE ( ! FAILED () );
+
     NGS_Alignment * mate = NGS_AlignmentGetMateAlignment ( m_align, ctx );
-    REQUIRE_NOT_NULL ( mate ); 
+    REQUIRE_NOT_NULL ( mate );
     REQUIRE ( ! FAILED () );
     NGS_RefcountRelease ( NGS_AlignmentToRefcount ( mate ) , ctx );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE_STRING ( "supercont2.1", NGS_AlignmentGetMateReferenceSpec ( m_align, ctx ) ); 
+
+    REQUIRE_STRING ( "supercont2.1", NGS_AlignmentGetMateReferenceSpec ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE ( NGS_AlignmentGetMateIsReversedOrientation ( m_align, ctx ) ); 
+
+    REQUIRE ( NGS_AlignmentGetMateIsReversedOrientation ( m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
+
+    NGS_AlignmentIsFirst ( m_align, ctx );
+    REQUIRE ( ! FAILED () );
+
     // fragment functions
-    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".FA0.1", NGS_FragmentGetId ( (NGS_Fragment*)m_align, ctx ) ); 
+    REQUIRE_STRING ( string ( CSRA1_PrimaryOnly ) + ".FA0.1", NGS_FragmentGetId ( (NGS_Fragment*)m_align, ctx ) );
     REQUIRE ( ! FAILED () );
-    
+
     REQUIRE_STRING (  "ACTCG",  NGS_FragmentGetSequence ( (NGS_Fragment*)m_align, ctx, 0, 5 ) );
     REQUIRE ( ! FAILED () );
-    
+
     REQUIRE_STRING ( "@@CDD",  NGS_FragmentGetQualities ( (NGS_Fragment*)m_align, ctx, 0, 5 ) );
     REQUIRE ( ! FAILED () );
-    
+
     REQUIRE ( ! NGS_FragmentIteratorNext ( (NGS_Fragment*)m_align, ctx ) );
     REQUIRE_FAILED ();
-    
+
     EXIT;
 }
 
@@ -322,65 +329,65 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_AccessAfterNext, CSRA1_Fixture)
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Primary, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false ); 
 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.1") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.2") ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false );
+
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.1") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.2") );
     // etc
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Primary_Only, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false ); 
+
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false );
 
     // skip to where a secondary alignment which would show up, between primary alignments 34 and 35
     SkipAlignments( 33 );
-    
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") ); 
-    
+
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") );
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Secondary, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, false, true ); 
 
-    
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.170") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.171") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.172") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.173") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.174") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.175") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.176") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.177") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.178") ); 
-    
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, false, true );
+
+
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.170") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.171") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.172") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.173") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.174") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.175") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.176") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.177") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.178") );
+
     REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_PrimaryAndSecondary, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true ); 
+
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true );
 
     // skip to where a secondary alignment is expected, between primary alignments 34 and 35
     SkipAlignments( 33 );
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") ); 
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") );
 
     EXIT;
 }
@@ -388,36 +395,36 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_PrimaryAndSecondary, CSRA1_Fixture)
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Sort, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true ); 
+
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true );
 
     // secondary 170 should go before primary 62
     SkipAlignments( 61 ); /*skip over 60 primary and 1 secondary */
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.61") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.170") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.62") ); 
-    
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.61") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.170") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.62") );
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_FullPrimary_Order, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, false );
     REQUIRE ( VerifyOrder() );
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_FullSecondary_Order, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, false, true ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, false, true );
     REQUIRE ( VerifyOrder() );
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_FullAll_Order, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true );
     REQUIRE ( VerifyOrder() );
     EXIT;
 }
@@ -425,23 +432,23 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_FullAll_Order, CSRA1_Fixture)
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Empty, CSRA1_Fixture)
 {
     ENTRY_GET_REF( "SRR960954", "gi|296100371|ref|NC_014121.1|" );
-    
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 0, 20000, false, false ); 
+
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 0, 20000, false, false );
     REQUIRE ( ! FAILED () );
-    
+
     REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_OutOfBounds, CSRA1_Fixture)
 {
     ENTRY_GET_REF( "SRR960954", "gi|296100371|ref|NC_014121.1|" );
-    
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, NGS_ReferenceGetLength ( m_ref, ctx ), 1, true, true ); 
+
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, NGS_ReferenceGetLength ( m_ref, ctx ), 1, true, true );
     REQUIRE ( ! FAILED () );
-    
+
     REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     EXIT;
 }
 
@@ -449,19 +456,19 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 517000, 100000, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 517000, 100000, true, true );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") ); 
-    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") ); 
-    
+
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.34") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".SA.169") );
+    REQUIRE ( NextId ( string ( CSRA1_WithSecondary ) + ".PA.35") );
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Order, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 517000, 100000, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 517000, 100000, true, true );
     REQUIRE ( VerifyOrder() );
     EXIT;
 }
@@ -471,11 +478,11 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_NoSecondary, CSRA1_Fixture)
     const char* accesssion = "SRR644545";
     ENTRY_GET_REF ( accesssion, "NC_000004.11" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 0, 100000, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 0, 100000, true, true );
     REQUIRE ( ! FAILED () );
-    
-    REQUIRE ( NextId ( string ( accesssion ) + ".PA.1") ); 
-    
+
+    REQUIRE ( NextId ( string ( accesssion ) + ".PA.1") );
+
     EXIT;
 }
 
@@ -483,19 +490,19 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_Primary, CSRA1_Fixture
 {
     ENTRY_GET_REF ( CSRA1_PrimaryOnly, "supercont2.1" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 10000, 100, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 10000, 100, true, true );
     REQUIRE ( ! FAILED () );
-    
+
     // 2 primary alignments start in the previous chunk and overlap with the chunk starting at 10000
-    REQUIRE ( NextId ( string ( CSRA1_PrimaryOnly ) + ".PA.96") ); 
-    REQUIRE ( NextId ( string ( CSRA1_PrimaryOnly ) + ".PA.97") ); 
-    
+    REQUIRE ( NextId ( string ( CSRA1_PrimaryOnly ) + ".PA.96") );
+    REQUIRE ( NextId ( string ( CSRA1_PrimaryOnly ) + ".PA.97") );
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_Primary_Order, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_PrimaryOnly, "supercont2.1" );
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 10000, 100, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 10000, 100, true, true );
     REQUIRE ( VerifyOrder() );
     EXIT;
 }
@@ -504,12 +511,12 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_Secondary, CSRA1_Fixtu
 {
     ENTRY_GET_REF ( "SRR960954", "gi|296100371|ref|NC_014121.1|" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 4020000, 100, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 4020000, 100, true, true );
     REQUIRE ( ! FAILED () );
-    
+
     // a secondary alignment starts in the previous chunk and overlaps with the chunk starting at 4020000
-    REQUIRE ( NextId ( string ( "SRR960954.SA.1384") ) ); 
-    
+    REQUIRE ( NextId ( string ( "SRR960954.SA.1384") ) );
+
     EXIT;
 }
 
@@ -517,26 +524,26 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_PrimaryAndSecondary, C
 {
     ENTRY_GET_REF ( "ERR225922", "2" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 203895000, 100, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 203895000, 100, true, true );
     REQUIRE ( ! FAILED () );
-    
+
     // several primary and secondary alignments start in the previous chunk and overlap with the chunk starting at 203895000
                                     // pos, len, mapq
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7023")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7024")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7025")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7026")    ) ); 
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7023")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7024")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7025")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7026")    ) );
     REQUIRE ( NextId ( string ( "ERR225922.PA.7028")    ) );    // 203894959, 76, 60 (higher MAPQ than 7027, same pos/len)
     REQUIRE ( NextId ( string ( "ERR225922.PA.7027")    ) );    // 203894959, 76, 60
     REQUIRE ( NextId ( string ( "ERR225922.PA.7029")    ) );    // 203894961, 76, 60 (same as 45681 but primary)
     REQUIRE ( NextId ( string ( "ERR225922.SA.45681")   ) );   // 203894961, 76, 60 (same as 7029 but secondary; id=45521+160 )
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7030")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7031")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")    ) ); 
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7030")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7031")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")    ) );
     REQUIRE ( NextId ( string ( "ERR225922.SA.45682")   ) );   // (id=45,521+161)
-    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) ); 
-    
+    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) );
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_PrimaryAndSecondary_Cutoff, CSRA1_Fixture)
@@ -545,13 +552,13 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_PrimaryAndSecondary_Cu
 
     m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 203895050, 100, true, true ); // increase offset by 50 bases
     REQUIRE ( ! FAILED () );
-    
+
     // compared to the test above, alignments that do not reach 50+ bases into the chunk are excluded
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")  ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")  ) ); 
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")  ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")  ) );
     REQUIRE ( NextId ( string ( "ERR225922.SA.45682") ) ); // 45,521+161
-    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) ); 
-    
+    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) );
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_PrimaryAndSecondary_FullCutoff, CSRA1_Fixture)
@@ -560,10 +567,10 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_PrimaryAndSecondary_Fu
 
     m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 203895150, 100, true, true ); // increase offset to exclude all overlaps
     REQUIRE ( ! FAILED () );
-    
+
     // none of the alignments reach 150+ bases into the chunk
-    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) ); 
-    
+    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) );
+
     EXIT;
 }
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Filtered, CSRA1_Fixture)
@@ -579,17 +586,17 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Filtered, CSRA1_Fixture)
 
     m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, 203894961, 100, wants_primary, wants_secondary, filters, no_map_qual ); // only the ones that start within the window
     REQUIRE ( ! FAILED () );
-    
+
     // only the alignments starting inside the slice (203894961)
     REQUIRE ( NextId ( string ( "ERR225922.PA.7029")    ) );    // 203894961, 76, 60 (same as 45681 but primary)
     REQUIRE ( NextId ( string ( "ERR225922.SA.45681")   ) );   // 203894961, 76, 60 (same as 7029 but secondary; id=45521+160 )
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7030")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7031")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")    ) ); 
-    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")    ) ); 
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7030")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7031")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7032")    ) );
+    REQUIRE ( NextId ( string ( "ERR225922.PA.7033")    ) );
     REQUIRE ( NextId ( string ( "ERR225922.SA.45682")   ) );   // (id=45,521+161)
-    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) ); 
-    
+    REQUIRE ( ! NGS_AlignmentIteratorNext ( m_align, m_ctx ) );
+
     EXIT;
 }
 
@@ -597,15 +604,15 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Filtered, CSRA1_Fixture)
 // FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_LookbackDiffersForPrimaryAndSecondary, CSRA1_Fixture)
 // FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Slice_Overlap_DefaultLookback, CSRA1_Fixture)
 
-// circular reference 
+// circular reference
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Circular, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithCircularReference, "chrM" );
 
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true ); 
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true );
     REQUIRE ( ! FAILED () );
-    
+
     // chrM is 16569 bases long          // pos, len, mapq
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511855081") );   // 16528, 42, 0   // last base 16528+42-1 = 16569 (mod 16569 = #0 in 0-based coord)
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511855600") );   // 16529, 41, 66
@@ -614,9 +621,9 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Circular, CSRA1_Fixture)
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511855597") );   // 16529, 41, 4
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511855596") );   // 16529, 41, 0
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511855599") );   // 16529, 41, 0
-    
+
     // ...
-    
+
     // TODO: make sure alignments do not reappear at the end of iteration!
     EXIT;
 }
@@ -625,7 +632,7 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Circular_Slice, CSRA1_Fixture)
 {
     ENTRY_GET_REF ( CSRA1_WithCircularReference, "chrM" );
 
-    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 1, 100, true, true ); 
+    m_align = NGS_ReferenceGetAlignmentSlice ( m_ref, ctx, 1, 100, true, true );
     REQUIRE ( ! FAILED () );
                                          // pos, len, mapq
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511856243") );   // -39, 41, 56
@@ -633,9 +640,9 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_Circular_Slice, CSRA1_Fixture)
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511856242") );   // -39, 41, 0
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511857002") );   // -38, 40, 74
     REQUIRE ( NextId ( string ( CSRA1_WithCircularReference ) + ".PA.4511857001") );   // -38, 40, 70
-    
+
     // ...
-   
+
     EXIT;
 }
 
@@ -647,34 +654,34 @@ uint64_t SliceLength = 100;
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_Wraparound, CSRA1_Fixture )
 {   // wraparound alignments overlapping with a slice
     ENTRY_GET_REF( CSRA1_WithCircularReference, "chrM" );
-    
+
     const bool wants_primary = true;
     const bool wants_secondary = true;
 #pragma message ( "filtering did not work prior to today's changes. I have set filter bits to allow this test to pass. the test should be fixed so that filters are set to the two desired flags." )
     const uint32_t no_filters = NGS_AlignmentFilterBits_pass_bad | NGS_AlignmentFilterBits_pass_dups;
     const int32_t no_map_qual = 0;
 
-    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, no_filters, no_map_qual ); 
+    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, no_filters, no_map_qual );
     REQUIRE ( ! FAILED () && m_align );
     REQUIRE ( NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     // the first returned alignment starts before the start of the circular reference, overlaps with slice
     int64_t pos = NGS_AlignmentGetAlignmentPosition ( m_align, ctx );
     REQUIRE_LT ( ( int64_t ) ( SliceOffset + SliceLength ), pos );
-    
+
     // check for overlap with the slice
     uint64_t refLen = NGS_ReferenceGetLength ( m_ref, ctx );
-    pos -= ( int64_t ) refLen; 
+    pos -= ( int64_t ) refLen;
     REQUIRE_GT ( ( int64_t ) 0, pos );
     REQUIRE_GE ( pos + NGS_AlignmentGetAlignmentLength( m_align, ctx ), SliceOffset );
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_Wraparound_StartInWindow, CSRA1_Fixture )
 {   // when StartInWindow filter is specified, it removes wraparound alignments as well
     ENTRY_GET_REF( CSRA1_WithCircularReference, "chrM" );
-    
+
     const bool wants_primary = true;
     const bool wants_secondary = true;
 #pragma message ( "filtering did not work prior to today's changes. I have set filter bits to allow this test to pass. the test should be fixed so that filters are set to the two desired flags." )
@@ -682,22 +689,22 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_Wraparound_StartI
         NGS_AlignmentFilterBits_start_within_window;
     const int32_t no_map_qual = 0;
 
-    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual ); 
+    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual );
     REQUIRE ( ! FAILED () && m_align );
     REQUIRE ( NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     // the first returned alignment starts inside the slice
     int64_t pos = NGS_AlignmentGetAlignmentPosition ( m_align, ctx );
     REQUIRE_LE ( ( int64_t ) SliceOffset, pos );
     REQUIRE_LT ( pos, ( int64_t ) ( SliceOffset + SliceLength ) );
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_NoWraparound, CSRA1_Fixture )
 {   // only removes wraparound alignments, not the ones starting before the slice
     ENTRY_GET_REF( CSRA1_WithCircularReference, "chrM" );
-    
+
     const bool wants_primary = true;
     const bool wants_secondary = true;
 #pragma message ( "filtering did not work prior to today's changes. I have set filter bits to allow this test to pass. the test should be fixed so that filters are set to the two desired flags." )
@@ -705,20 +712,20 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_NoWraparound, CSR
         NGS_AlignmentFilterBits_no_wraparound;
     const int32_t no_map_qual = 0;
 
-    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual ); 
+    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual );
     REQUIRE ( ! FAILED () && m_align );
     REQUIRE ( NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     // the first returned alignment starts outside the slice but does not wrap around
     REQUIRE_GT ( ( int64_t ) SliceOffset, NGS_AlignmentGetAlignmentPosition ( m_align, ctx ) );
-    
+
     EXIT;
 }
 
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_NoWraparound_StartInWindow, CSRA1_Fixture )
 {   // when StartInWindow filter is specified, it removes wraparound alignments as well
     ENTRY_GET_REF( CSRA1_WithCircularReference, "chrM" );
-    
+
     const bool wants_primary = true;
     const bool wants_secondary = true;
 #pragma message ( "filtering did not work prior to today's changes. I have set filter bits to allow this test to pass. the test should be fixed so that filters are set to the two desired flags." )
@@ -726,15 +733,15 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetFilteredAlignmentSlice_NoWraparound_Star
         NGS_AlignmentFilterBits_no_wraparound | NGS_AlignmentFilterBits_start_within_window;
     const int32_t no_map_qual = 0;
 
-    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual ); 
+    m_align = NGS_ReferenceGetFilteredAlignmentSlice ( m_ref, ctx, SliceOffset, SliceLength, wants_primary, wants_secondary, filters, no_map_qual );
     REQUIRE ( ! FAILED () && m_align );
     REQUIRE ( NGS_AlignmentIteratorNext ( m_align, ctx ) );
-    
+
     // the first returned alignment starts inside the slice
     int64_t pos = NGS_AlignmentGetAlignmentPosition ( m_align, ctx );
     REQUIRE_LE ( ( int64_t ) SliceOffset, pos );
     REQUIRE_LT ( pos, ( int64_t ) ( SliceOffset + SliceLength ) );
-    
+
     EXIT;
 }
 
@@ -748,8 +755,8 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_PrintEmAll_1, CSRA1_Fixture)
 //    ENTRY_GET_REF ( CSRA1_WithSecondary, "gi|169794206|ref|NC_010410.1|" );
 //    ENTRY_GET_REF ( CSRA1_PrimaryOnly, "supercont2.1" );
     ENTRY_GET_REF ( CSRA1_WithCircularReference, "chrM" );
-    
-    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true ); 
+
+    m_align = NGS_ReferenceGetAlignments ( m_ref, ctx, true, true );
 
     uint64_t prevPos = 0;
     uint64_t prevLen = 0;
@@ -757,16 +764,16 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_PrintEmAll_1, CSRA1_Fixture)
     int      prevMapq = 0;
     while ( NGS_AlignmentIteratorNext ( m_align, ctx ) )
     {
-        
+
         uint64_t newPos = NGS_AlignmentGetAlignmentPosition ( m_align, m_ctx );
         uint64_t newLen = NGS_AlignmentGetAlignmentLength ( m_align, m_ctx );
         bool     newIsPrimary = NGS_AlignmentIsPrimary ( m_align, m_ctx );
         int      newMapq = NGS_AlignmentGetMappingQuality( m_align, m_ctx );
-        
+
         PrintAlignment ();
-        
+
 /*        REQUIRE_LE (prevPos, newPos);
-        if ( prevPos == newPos ) 
+        if ( prevPos == newPos )
         {
             REQUIRE_GE ( prevLen, newLen );
             if ( prevLen == newLen )
@@ -783,7 +790,7 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceWindow_PrintEmAll_1, CSRA1_Fixture)
         prevIsPrimary = newIsPrimary;
         prevMapq = newMapq;
     }
-    
+
     EXIT;
 }
 #endif
@@ -811,6 +818,7 @@ const char UsageDefaultName[] = "test-ngs_csra1_refwin";
 
 rc_t CC KMain ( int argc, char *argv [] )
 {
+    KConfigDisableUserSettings();
     rc_t m_coll=NgsCsra1RefWinTestSuite(argc, argv);
     return m_coll;
 }
