@@ -27,7 +27,7 @@
 /**
 * Unit tests for NGS C interface, reference accessions
 */
-
+#include <klib/debug.h> /* KDbgSetString */
 #include "ngs_c_fixture.hpp"
 
 #include <string.h>
@@ -50,6 +50,8 @@ using namespace ncbi::NK;
 
 TEST_SUITE(NgsReferenceTestSuite);
 
+#define ALL
+
 const char* CSRA1_PrimaryOnly   = "SRR1063272";
 const char* CSRA1_WithSecondary = "SRR833251";
 const char* CSRA1_WithCircularReference = "SRR1769246";
@@ -79,7 +81,7 @@ public:
 
     NGS_Alignment*      m_align;
 };
-
+#ifdef ALL
 // NGS_Reference
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetCommonName, CSRA1_ReferenceFixture)
 {
@@ -209,7 +211,7 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetAlignments_WithSecondary_Secondary, CSRA
 }
 
 
-// ReferenceGetAlignments on circular references
+// ReferenceGetFilteredAlignments on circular references
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetAlignments_Circular_Wraparound, CSRA1_ReferenceFixture)
 {
     ENTRY_GET_REF( CSRA1_WithCircularReference, "NC_012920.1" );
@@ -505,6 +507,48 @@ FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceGetBlobs, CSRA1_ReferenceFixture)
     EXIT;
 }
 
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceIsLocal_Yes, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF( CSRA1_PrimaryOnly, "supercont2.1" );
+    REQUIRE ( NGS_ReferenceGetIsLocal ( m_ref, ctx ) );
+    EXIT;
+}
+
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceIsLocal_No, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF( "SRR821492", "chrM" );
+    REQUIRE ( ! NGS_ReferenceGetIsLocal ( m_ref, ctx ) );
+    EXIT;
+}
+
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceIsLocalSRR619505, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF("SRR619505", "NC_000005.8");
+    REQUIRE(!NGS_ReferenceGetIsLocal(m_ref, ctx));
+    EXIT;
+}
+
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceIsLocalSRR413283, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF("SRR413283", "FLT3_NM_004119.2");
+    REQUIRE(NGS_ReferenceGetIsLocal(m_ref, ctx));
+    EXIT;
+}
+
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceNotLocalSRR413283, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF("SRR496123", "NC_007112.5");
+    REQUIRE(!NGS_ReferenceGetIsLocal(m_ref, ctx));
+    EXIT;
+}
+
+FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceLocalSRR413283, CSRA1_ReferenceFixture)
+{
+    ENTRY_GET_REF("SRR496123", "NC_002333.2");
+    REQUIRE(NGS_ReferenceGetIsLocal(m_ref, ctx));
+    EXIT;
+}
+
 // Iteration over References
 FIXTURE_TEST_CASE(CSRA1_NGS_ReferenceIterator_GetLength_1, CSRA1_ReferenceFixture)
 {
@@ -645,31 +689,44 @@ FIXTURE_TEST_CASE(SRA_Reference_Open_FailsOnNonReference, NGS_C_Fixture)
     REQUIRE_FAILED ();
     EXIT;
 }
+#endif
+
+#include <unistd.h> // gethostname
+static bool expectToFail() {
+    char name[512] ="";
+    gethostname(name, sizeof name);
+    std::cerr << "GETHOSTNAME = '" << name << "': ";
+    const char bad[]="tcmac0";
+    if (strncmp(name,bad, sizeof bad - 1) == 0) {
+      std::cerr << "bad host\n";
+      return true;
+    }
+    std::cerr << "good host\n";
+    return false;
+}
 
 FIXTURE_TEST_CASE(EBI_Reference_Open_EBI_MD5, NGS_C_Fixture)
 {
 /* The following request should success it order to this test to work:
-http://www.ebi.ac.uk/ena/cram/md5/ffd6aeffb54ade3d28ec7644afada2e9
-Otherwise CALL_TO_EBI_RESOLVER_FAILS is set
-and this test is expected to fail */
-    const bool CALL_TO_EBI_RESOLVER_FAILS = //false;
-true;
+   https://www.ebi.ac.uk/ena/cram/md5/ffd6aeffb54ade3d28ec7644afada2e9
+   Otherwise CALL_TO_EBI_RESOLVER_FAILS is set
+   and this test is expected to fail
+It is known to fail on macs with old certificates file */
+    const bool CALL_TO_EBI_RESOLVER_FAILS = expectToFail();
 
     ENTRY;
     const char* EBI_Accession = "ffd6aeffb54ade3d28ec7644afada2e9";
 
-    if ( CALL_TO_EBI_RESOLVER_FAILS ) {
-    }
-
     NGS_ReferenceSequence * ref = NGS_ReferenceSequenceMake ( ctx, EBI_Accession );
 
+// does not seem to fail on tcmacXXs anymore
     if ( CALL_TO_EBI_RESOLVER_FAILS ) {
-        REQUIRE ( FAILED () );
-        REQUIRE_NULL ( ref );
-        LOG(ncbi::NK::LogLevel::e_error,
-            "CANNOT TEST EBI ACCESSION BECAUSE THEIR SITE DOES NOT RESPOND!\n");
-        LOG(ncbi::NK::LogLevel::e_error, "NOW EXPECTING AN ERROR MESSAGE ...");
-        return;
+//        REQUIRE ( FAILED () );
+//        REQUIRE_NULL ( ref );
+//        LOG(ncbi::NK::LogLevel::e_error,
+//            "CANNOT TEST EBI ACCESSION BECAUSE THEIR SITE DOES NOT RESPOND!\n");
+//        LOG(ncbi::NK::LogLevel::e_error, "NOW EXPECTING AN ERROR MESSAGE ...");
+//        return;
     }
 
     REQUIRE ( ! FAILED () );
@@ -688,7 +745,7 @@ true;
     NGS_ReferenceSequenceRelease ( ref, ctx );
     EXIT;
 }
-
+#ifdef ALL
 FIXTURE_TEST_CASE(EBI_Reference_Open_EBI_ACC, NGS_C_Fixture)
 {
     ENTRY;
@@ -706,7 +763,7 @@ FIXTURE_TEST_CASE(EBI_Reference_Open_EBI_ACC, NGS_C_Fixture)
     NGS_ReferenceSequenceRelease ( ref, ctx );
     EXIT;
 }
-
+#endif
 //////////////////////////////////////////// Main
 extern "C"
 {
@@ -732,8 +789,24 @@ const char UsageDefaultName[] = "test-ngs_reference";
 rc_t CC KMain ( int argc, char *argv [] )
 {
     KConfigDisableUserSettings();
-    rc_t m_coll=NgsReferenceTestSuite(argc, argv);
-    return m_coll;
+
+    if(
+0)
+        assert(!KDbgSetString("KNS-HTTP"));
+
+    KConfig * kfg = NULL;
+    rc_t rc = KConfigMake(&kfg, NULL);
+
+    // turn off certificate validation to download EBI reference
+    if (rc == 0)
+        rc = KConfigWriteString(kfg, "/tls/allow-all-certs", "true");
+
+    if (rc == 0)
+        rc = NgsReferenceTestSuite(argc, argv);
+
+    KConfigRelease(kfg);
+
+    return rc;
 }
 
 }
