@@ -36,6 +36,8 @@
 
 #include <kdb/manager.h>
 
+#include <kfg/config.h> /* KConfigDisableUserSettings */
+
 #include <vdb/manager.h>
 #include <vdb/vdb-priv.h>
 
@@ -858,6 +860,7 @@ const char UsageDefaultName[] = "test-ngs_sra";
 
 rc_t CC KMain ( int argc, char *argv [] )
 {
+    KConfigDisableUserSettings();
     rc_t m_coll=NgsSradbTestSuite(argc, argv);
     return m_coll;
 }
